(************** Content-type: application/mathematica **************

                     Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
   with a name ending in .nb, then open the file inside the
   application;

* Copy the data starting with the line of stars above to the
   clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible
applications, contact Wolfram Research:
   web: http://www.wolfram.com
   email: info@wolfram.com
   phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     53496,       1436]*)
(*NotebookOutlinePosition[     95159,       2838]*)
(*  CellTagsIndexPosition[     95031,       2831]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
   "Electronic structure calculation for ",
   StyleBox["N",
     FontSlant->"Italic"],
   "\[Dash]",
   "electron quantum dots"
}], "Title",
   TextAlignment->Center,
   TextJustification->0,
   FontFamily->"Times",
   CellTags->"Title"],

Cell[TextData[{
   "This package defines the functions and modules required to implement \
Hartree\[Dash]Fock calculations for two\[Dash]dimensional circularly \
symmetric quantum dot systems with ",
   StyleBox["N",
     FontSlant->"Italic"],
   "\[Dash]electrons."
}], "Text",
   TextAlignment->Left,
   TextJustification->1],

Cell[TextData[{
   "There are no special requirements for running this program in ",
   StyleBox["Mathematica ",
     FontSlant->"Italic"],
   "version 4.1 or later. To execute the program, simply enter any cell \
(either in the Package or Example sections below).  The executable code \
(flagged using Initialization cells) will be automatically loaded.  Once this \
code is loaded, the user has full access to all of the Hartree-Fock functions \
and modules."
}], "Text"],

Cell["\[Copyright] Shane McCarthy, Jingbo Wang and Paul Abbott, 2000, 2001.", \
"Text",
   TextAlignment->Center,
   TextJustification->0],

Cell[CellGroupData[{

Cell[TextData[{

   CounterBox["Section"],
   ". Package"
}], "Section",
   FontFamily->"Times"],

Cell[CellGroupData[{

Cell[TextData[{

   CounterBox["Section"],
   ".",

   CounterBox["Subsection"],
   ". Initialisation"
}], "Subsection"],

Cell["\<\
We first turn off some warning messages, and define a few useful \
notations for the Coulomb and exchange integrals.\
\>", "Text"],

Cell[BoxData[
     \(TraditionalForm\`Off[General::"\<spell\>"];
     Off[General::"\<spell1\>"];\)], "Input",
   InitializationCell->True],

Cell[BoxData[
     \(TraditionalForm\`Needs["\<Utilities`Notation`\>"]\)], "Input",
   InitializationCell->True],

Cell[BoxData[
     \(TraditionalForm\`\(SetOptions[Notation,
         WorkingForm \[Rule] TraditionalForm];\)\)], "Input",
   InitializationCell->True],

Cell[BoxData[
     FormBox[
       RowBox[{"Notation", "[",
         RowBox[{

           TagBox[\(\[ScriptCapitalI]\_\(i_, j_\)\%d[\[Lambda]_, \
\[ScriptCapitalS]_, \[ScriptCapitalN]_, k_, \[Eta]_]\),
             NotationBoxTag], " ", "\[DoubleLongLeftRightArrow]", " ",

           TagBox[\(CoulombIntegral[i_,
               j_, \[Lambda]_, \[ScriptCapitalS]_, \[ScriptCapitalN]_,
               k_, \[Eta]_]\),
             NotationBoxTag]}], "]"}], TraditionalForm]], "Input",
   InitializationCell->True],

Cell[BoxData[
     FormBox[
       RowBox[{"Notation", "[",
         RowBox[{
           TagBox[
             RowBox[{
               SubsuperscriptBox["\[ScriptCapitalI]", \(i_, j_\),
                 StyleBox["ex",
                   FontSlant->"Italic"]],
               "[", \(\[Lambda]_, \[ScriptCapitalS]_, \[ScriptCapitalN]_,
               k_, \[Eta]_\), "]"}],
             NotationBoxTag], " ", "\[DoubleLongLeftRightArrow]", " ",

           TagBox[\(ExchangeIntegral[i_,
               j_, \[Lambda]_, \[ScriptCapitalS]_, \[ScriptCapitalN]_,
               k_, \[Eta]_]\),
             NotationBoxTag]}], "]"}], TraditionalForm]], "Input",
   InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{

   CounterBox["Section"],
   ".",

   CounterBox["Subsection"],
   ". Matrix Elements"
}], "Subsection"],

Cell["\<\
The basis functions for the Rayleigh-Ritz variational method are \
defined by\
\>", "Text"],

Cell[BoxData[
     \(TraditionalForm\`\(v /: v\_\(i_, m_\) =
         Function[{k,
             r}, \[ExponentialE]\^\(\(-\(k\/2\)\)\ r\^2\)\ r\^m\ \(\(L\_i\%m\)(
               k\ r\^2)\)];\)\)], "Input",
   InitializationCell->True],

Cell["\<\
A function from the simplification of Coulomb and exchange \
potentials in the Hartree-Fock equations is defined by\
\>", "Text"],

Cell[BoxData[
     \(TraditionalForm\`\[GothicCapitalV] /: \[GothicCapitalV]\_m_ := \(\
\[GothicCapitalV] /: \[GothicCapitalV]\_m =
         Function[{\[Xi]},
           Evaluate[
             FullSimplify[
               Collect[Simplify[\((1 - \[Xi])\)\ \(\[Integral]\_0\%\(2\ \
\[Pi]\)\(\(cos(
                               m\ \[Phi])\)\/\@\(\[Xi]\^2 - 2\ \(cos(\[Phi])\)\
\ \[Xi] + 1\)\) \[DifferentialD]\[Phi]\), 0 \[LessEqual] \[Xi] < 1], {K(_),
                   E(_), \[Xi]}, Simplify]]]]\)\)], "Input",
   InitializationCell->True],

Cell["\<\
The Ritz matrix, \[ScriptCapitalA] and the overlap matrix, \
\[ScriptCapitalB] of dimension \[ScriptCapitalN] are defined by\
\>", "Text"],

Cell[BoxData[
     FormBox[
       RowBox[{
       "\[ScriptCapitalA]", "/:", 
\(\[ScriptCapitalA]\_\[ScriptCapitalN]_\), ":=",

         RowBox[{"Function", "[",
           RowBox[{\({\[Lambda], \[ScriptCapitalS], k, V0, \[Eta]}\), ",",
             RowBox[{"Table", "[",
               RowBox[{

                 RowBox[{\(\[Alpha]\_\(i, j\)[
                     k, \[LeftBracketingBar]\[Lambda]\[LeftDoubleBracket]2\
\[RightDoubleBracket]\[RightBracketingBar]]\), "+",
                   RowBox[{\(\[ScriptCapitalV]\_\(i, j\)\), "[",
                     RowBox[{"k", ",", "V0", ",",

                       FormBox[\(\[LeftBracketingBar]\[Lambda]\
\[LeftDoubleBracket]2\[RightDoubleBracket]\[RightBracketingBar]\),
                         "TraditionalForm"]}], "]"}],
                   "+", \(\[ScriptCapitalI]\_\(i, j\)\%d[\[Lambda], \
\[ScriptCapitalS], \[ScriptCapitalN], k, \[Eta]]\), "-",
                   RowBox[{
                     SubsuperscriptBox["\[ScriptCapitalI]", \(i, j\),
                       StyleBox["ex",
                         FontSlant->"Italic"]],
                     "[", \(\[Lambda], \[ScriptCapitalS], \[ScriptCapitalN],
                     k, \[Eta]\), "]"}]}],
                 ",", \({i, 0, \[ScriptCapitalN] - 1}\),
                 ",", \({j, 0, \[ScriptCapitalN] - 1}\)}], "]"}]}], "]"}]}],
       TraditionalForm]], "Input",
   InitializationCell->True],

Cell[BoxData[
     FormBox[
       RowBox[{
       "\[ScriptCapitalB]", "/:", 
\(\[ScriptCapitalB]\_\[ScriptCapitalN]_\), ":=",

         RowBox[{"Function", "[",
           RowBox[{\({k, m}\), ",",
             RowBox[{"Table", "[",
               RowBox[{
                 RowBox[{\(\[Beta]\_\(i, j\)\), "[",
                   RowBox[{"k", ",",
                     FormBox[\(\[LeftBracketingBar]m\[RightBracketingBar]\),
                       "TraditionalForm"]}], "]"}],
                 ",", \({i, 0, \[ScriptCapitalN] - 1}\),
                 ",", \({j, 0, \[ScriptCapitalN] - 1}\)}], "]"}]}], "]"}]}],
       TraditionalForm]], "Input",
   InitializationCell->True],

Cell["\<\
The individual components of these matrices are given by the \
integrals given below.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
   "Kinetic energy integrals, ",
   Cell[BoxData[
       \(TraditionalForm\`\[Alpha]\_\(i\[InvisibleComma]j\)\)]]
}], "Subsubsection"],

Cell[BoxData[
     FormBox[
       RowBox[{
         RowBox[{\(\[Alpha]\_\(i_, j_\)[k_, m_] /; j > i\), "=",
           FractionBox[
             RowBox[{\(\((i + m + 1)\)!\), " ",
               SubscriptBox[
                 InterpretationBox["\[Delta]",
                   KroneckerDelta,
                   Editable->False,
                   Selectable->False], \(i + 1, j\)]}], \(4  k\^m\ \(i!\)\)]}],
          ";"}], TraditionalForm]], "Input",
   InitializationCell->True],

Cell[BoxData[
     \(TraditionalForm\`\(\[Alpha]\_\(i_, j_\)[k_, m_] /;
           i > j = \[Alpha]\_\(j, i\)[k, m];\)\)], "Input",
   InitializationCell->True],

Cell[BoxData[
     \(TraditionalForm\`\(\[Alpha]\_\(i_, i_\)[k_,
           m_] = \(\((2\ i + m + 1)\)\ \(\((i + m)\)!\)\)\/\(4  k\^m\ \
\(i!\)\);\)\)], "Input",
   InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
   "Overlap integrals, ",
   Cell[BoxData[
       \(TraditionalForm\`\[Beta]\_\(i\[InvisibleComma]j\)\)]]
}], "Subsubsection"],

Cell[BoxData[
     FormBox[
       RowBox[{
         RowBox[{\(\[Beta]\_\(i_, i_\)[k_, m_]\), "=",
           RowBox[{\(1\/\(2\ k\^\(m + 1\)\)\),
             FractionBox[
               FormBox[\(\((i + m)\)!\),
                 "TraditionalForm"], \(i!\)]}]}], ";"}],
       TraditionalForm]], "Input",
   InitializationCell->True],

Cell[BoxData[
     \(TraditionalForm\`\(\[Beta]\_\(i_, j_\)[k_, m_] = 0;\)\)], "Input",
   InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
   "Confining potential integrals, ",
   Cell[BoxData[
       \(TraditionalForm\`\[ScriptCapitalV]\_\(i\[InvisibleComma]j\)\)]]
}], "Subsubsection"],

Cell[TextData[{
   "This definition is for a harmonic confining potential of the form ",
   Cell[BoxData[
       \(TraditionalForm\`V(r) = \(-V\_0\) + \(1\/2\) k\^2\ r\^2\)]],
   "."
}], "Text"],

Cell[BoxData[
     FormBox[
       RowBox[{
       "\[ScriptCapitalV]", "/:", \(\[ScriptCapitalV]\_\(i_, j_\)\), ":=",
         RowBox[{
         "\[ScriptCapitalV]", "/:", \(\[ScriptCapitalV]\_\(i, j\)\), "=",
           RowBox[{
           "\[ScriptCapitalV]", "/:", \(\[ScriptCapitalV]\_\(j, i\)\), "=",
             RowBox[{"Function", "[",
               RowBox[{\({k, V0, m}\), ",",
                 RowBox[{"Evaluate", "[",
                   RowBox[{
                     FractionBox["1",
                       RowBox[{"4", " ", \(k\^m\), " ",
                         FormBox[\(i!\),
                           "TraditionalForm"]}]],
                     RowBox[{"(", " ",
                       RowBox[{

                         RowBox[{\((\((2\ i + m + 1)\) - \(2\ V0\)\/k)\),
                           " ", \(\((i + m)\)!\), " ",
                           SubscriptBox[
                             InterpretationBox["\[Delta]",
                               KroneckerDelta,
                               Editable->False,
                               Selectable->False], \(i, j\)]}], " ", "-",
                         RowBox[{"i", " ", \(\((i + m)\)!\), " ",
                           SubscriptBox[
                             InterpretationBox["\[Delta]",
                               KroneckerDelta,
                               Editable->False,
                               Selectable->False], \(i - 1, j\)]}], "-",
                         RowBox[{\(\((i + m + 1)\)!\), " ",
                           SubscriptBox[
                             InterpretationBox["\[Delta]",
                               KroneckerDelta,
                               Editable->False,
                               Selectable->False], \(i + 1, j\)]}]}], ")"}]}],
                   "]"}]}], "]"}]}]}]}], TraditionalForm]], "Input",
   InitializationCell->True],

Cell["\<\
The solution for a gaussian confining potential is given in the \
examples section.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
   "Coulomb integrals, ",
   Cell[BoxData[
       \(TraditionalForm\`\[ScriptCapitalI]\_\(i\[InvisibleComma]j\)\%d\)]]
}], "Subsubsection"],

Cell[BoxData[
     FormBox[
       RowBox[{\(\[ScriptCapitalI]\_\(i_, j_\)\%d[\[Lambda]_, \
\[ScriptCapitalS]_, \[ScriptCapitalN]_, k_, \[Eta]_]\), ":=",
         RowBox[{"Module", "[",
           RowBox[{\({\[Sigma]}\), ",", "\[IndentingNewLine]",

             RowBox[{\(\[Sigma] = DeleteCases[\[ScriptCapitalS], \[Lambda]]\),
               ";", "\[IndentingNewLine]",
               RowBox[{\(1\/2\), " ",
                 RowBox[{\(\[Sum]\+\(\[Kappa] = 1\)\%\(Length[\[Sigma]]\)\),
                   RowBox[{\(\[Sum]\+\(p = 1\)\%\[ScriptCapitalN]\),
                     RowBox[{\(\[Sum]\+\(q = 1\)\%\[ScriptCapitalN]\),
                       RowBox[{
                         RowBox[{

                           FormBox[\(\(\ \)\(c\_\(\[Sigma]\[LeftDoubleBracket]\
\[Kappa]\[RightDoubleBracket], \[Eta]\)\)\),
                             "TraditionalForm"], "\[LeftDoubleBracket]", "p",
                           "\[RightDoubleBracket]"}], " ",
                         RowBox[{
                           FormBox[

                             FormBox[\(c\_\(\[Sigma]\[LeftDoubleBracket]\
\[Kappa]\[RightDoubleBracket], \[Eta]\)\),
                               "TraditionalForm"],
                             "TraditionalForm"], "\[LeftDoubleBracket]", "q",
                           "\[RightDoubleBracket]"}],
                         " ", \(k\^\(\(-\[LeftBracketingBar]\[Lambda]\
\[LeftDoubleBracket]2\[RightDoubleBracket]\[RightBracketingBar]\) - \
\[LeftBracketingBar]\[Sigma]\[LeftDoubleBracket]\[Kappa],
                                   2\[RightDoubleBracket]\[RightBracketingBar] \
- 3\/2\)\), " ", \(\[GothicD][{i,
                             j, \[LeftBracketingBar]\[Lambda]\
\[LeftDoubleBracket]2\[RightDoubleBracket]\[RightBracketingBar]}, {p - 1,
                             q - 1, \[LeftBracketingBar]\[Sigma]\
\[LeftDoubleBracket]\[Kappa],
                                 2\[RightDoubleBracket]\[RightBracketingBar]}]\
\)}]}]}]}]}]}]}], "]"}]}], TraditionalForm]], "Input",
   InitializationCell->True],

Cell["\<\
with the integral \[GothicD] defined below.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
   "Exchange integrals, ",
   Cell[BoxData[
       FormBox[
         SubsuperscriptBox["\[ScriptCapitalI]", \(i\[InvisibleComma]j\),
           StyleBox["ex",
             FontSlant->"Italic"]], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
     FormBox[
       RowBox[{
         RowBox[{
           SubsuperscriptBox["\[ScriptCapitalI]", \(i_, j_\),
             StyleBox["ex",
               FontSlant->"Italic"]],
           "[", \(\[Lambda]_, \[ScriptCapitalS]_, \[ScriptCapitalN]_,
           k_, \[Eta]_\), "]"}],
         ":=", \(Module[{\[Sigma]}, \[IndentingNewLine]\[Sigma] =
             DeleteCases[
               DeleteCases[\[ScriptCapitalS], \[Lambda]], {_, _, \(-\[Lambda]\
\[LeftDoubleBracket]3\[RightDoubleBracket]\)}]; \[IndentingNewLine]1\/2\ \(\
\[Sum]\+\(\[Kappa] = 1\)\%\(Length[\[Sigma]]\)\(\[Sum]\+\(p = 1\)\%\
\[ScriptCapitalN]\(\[Sum]\+\(q = 1\)\%\[ScriptCapitalN] c\_\(\[Sigma]\
\[LeftDoubleBracket]\[Kappa]\[RightDoubleBracket], \[Eta]\)\
\[LeftDoubleBracket]
                       p\[RightDoubleBracket]\ c\_\(\[Sigma]\
\[LeftDoubleBracket]\[Kappa]\[RightDoubleBracket], \[Eta]\)\
\[LeftDoubleBracket]
                       q\[RightDoubleBracket]\ k\^\(\(-\[LeftBracketingBar]\
\[Lambda]\[LeftDoubleBracket]2\[RightDoubleBracket]\[RightBracketingBar]\) - \
\[LeftBracketingBar]\[Sigma]\[LeftDoubleBracket]\[Kappa], 2\
\[RightDoubleBracket]\[RightBracketingBar] - 3\/2\)\ \[GothicF][{i,
                         j, \[Lambda]\[LeftDoubleBracket]2\[RightDoubleBracket]\
}, {p - 1, q - 1, \[Sigma]\[LeftDoubleBracket]\[Kappa],
                           2\[RightDoubleBracket]}]\)\)\)]\)}],
       TraditionalForm]], "Input",
   InitializationCell->True],

Cell["\<\
with the integral \[GothicF] defined below.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
   StyleBox["\[GothicD]",
     FontSlant->"Plain"],
   " and ",
   StyleBox["\[GothicF]",
     FontSlant->"Plain"]
}], "Subsubsection"],

Cell[BoxData[
     FormBox[
       RowBox[{\(\[GothicD][{i_, j_, m_}, {p_, q_, n_}]\), ":=",
         RowBox[{\(\[GothicD][{i, j, m}, {p, q, n}]\), "=",
           RowBox[{\(\[GothicD][{i, j, m}, {q, p, n}]\), "=",
             RowBox[{\(\[GothicD][{j, i, m}, {p, q, n}]\), "=",

               RowBox[{\(\[GothicD][{j, i, m}, {q, p, n}]\), "=",
                 "\[IndentingNewLine]",
                 RowBox[{"NIntegrate", "[",
                   RowBox[{
                     RowBox[{"Evaluate", "[",

                       RowBox[{\(1\/\(2\ \[Pi]\)\),
                         " ", \(\[Xi]\^\(2\ n + 1\)\), " ",
                         FractionBox[\(\[GothicCapitalV]\_0[\[Xi]]\),

                           FormBox[\(\[LeftBracketingBar]1 - \[Xi]\
\[RightBracketingBar]\),
                             "TraditionalForm"]],
                         "  ", \(\[LeftAngleBracket]{i, j}, {p, q},
                             1\[RightAngleBracket][m, n, \[Xi]]\)}], "]"}],
                     ",", \({\[Xi], 0, 1, \[Infinity]}\)}], "]"}]}]}]}]}]}],
       TraditionalForm]], "Input",
   InitializationCell->True],

Cell[BoxData[
     FormBox[
       RowBox[{\(\[GothicF][{i_, j_, m_}, {p_, q_, n_}]\), ":=",
         "\[IndentingNewLine]",
         RowBox[{\(\[GothicF][{i, j, m}, {p, q, n}]\), "=",
           RowBox[{\(\[GothicF][{p, q, n}, {i, j, m}]\), "=",
             RowBox[{\(\[GothicF][{i, j, \(-m\)}, {p, q, \(-n\)}]\), "=",

               RowBox[{\(\[GothicF][{p, q, \(-n\)}, {i, j, \(-m\)}]\), "=",
                 "\[IndentingNewLine]",
                 RowBox[{"NIntegrate", "[",
                   RowBox[{
                     RowBox[{"Evaluate", "[",
                       RowBox[{\(1\/\(2  \[Pi]\)\), " ",
                         SuperscriptBox["\[Xi]",
                           RowBox[{
                             RowBox[{"2", " ",

                               FormBox[\(\[LeftBracketingBar]n\
\[RightBracketingBar]\),
                                 "TraditionalForm"]}], "+", "1"}]], " ",
                         FractionBox[
                           RowBox[{
                             SubscriptBox["\[GothicCapitalV]",

                               FormBox[\(\[LeftBracketingBar]m -
                                     n\[RightBracketingBar]\),
                                 "TraditionalForm"]], "[", "\[Xi]", "]"}],

                           FormBox[\(\[LeftBracketingBar]1 - \[Xi]\
\[RightBracketingBar]\),
                             "TraditionalForm"]], "  ",

                         RowBox[{\(\[LeftAngleBracket]{i, j}, {p, q},
                             2\[RightAngleBracket]\), "[",
                           RowBox[{

                             FormBox[\(\[LeftBracketingBar]m\
\[RightBracketingBar]\),
                               "TraditionalForm"], ",",

                             FormBox[\(\[LeftBracketingBar]n\
\[RightBracketingBar]\),
                               "TraditionalForm"], ",", "\[Xi]"}], "]"}]}],
                       "]"}], ",", \({\[Xi], 0, 1, \[Infinity]}\)}],
                   "]"}]}]}]}]}]}], TraditionalForm]], "Input",
   InitializationCell->True],

Cell[TextData[{
   "with ",
   Cell[BoxData[
       \(TraditionalForm\`\[LeftAngleBracket]{i, j}, {p, q},
         1\[RightAngleBracket]\)]],
   " and ",
   Cell[BoxData[
       \(TraditionalForm\`\[LeftAngleBracket]{i, j}, {p, q},
         2\[RightAngleBracket]\)]],
   " defined by"
}], "Text"],

Cell[BoxData[
     \(TraditionalForm\`\[LeftAngleBracket]{i_, j_}, {p_, q_},
         1\[RightAngleBracket] := \(\[LeftAngleBracket]{i, j}, {p, q},
           1\[RightAngleBracket] = \(\[LeftAngleBracket]{j, i}, {p, q},
             1\[RightAngleBracket] = \(\[LeftAngleBracket]{i, j}, {q, p},
               1\[RightAngleBracket] = \(\[LeftAngleBracket]{j, i}, {q, p},
                 1\[RightAngleBracket] =
               Function[{m, n, \[Xi]},
                 Evaluate[\((\[Xi]\^2 + 1)\)\^\(\(-m\) - n - 3\/2\)\ Collect[
                         Expand[
                           x\^a\ r\^b\ \(\(L\_p\%n\)(x)\)\ \(\(L\_q\%n\)(
                               x)\)\ \(\(L\_i\%m\)(r)\)\ \(\(L\_j\%m\)(
                               r)\)], {x\^\(_ : 1\)\ r\^\(_ : 1\)},
                         Simplify] /. \[InvisibleSpace]c_. \ x\^\(a + \[Eta]_. \
\)\ r\^\(b + l_. \) \[RuleDelayed]
                       c\ \(\(\[ScriptCapitalI]\_\(l, \[Eta], m,
                               n\)\)(\[Xi])\)]]\)\)\)\)\)], "Input",
   InitializationCell->True],

Cell[BoxData[
     \(TraditionalForm\`\[LeftAngleBracket]{i_, j_}, {p_, q_},
         2\[RightAngleBracket] := \(\[LeftAngleBracket]{i, j}, {p, q},
           2\[RightAngleBracket] = \(\[LeftAngleBracket]{j, i}, {p, q},
             2\[RightAngleBracket] = \(\[LeftAngleBracket]{i, j}, {q, p},
               2\[RightAngleBracket] = \(\[LeftAngleBracket]{j, i}, {q, p},
                 2\[RightAngleBracket] =
               Function[{m, n, \[Xi]},
                 Evaluate[\((\[Xi]\^2 + 1)\)\^\(\(-m\) - n - 3\/2\)\ Collect[
                         Expand[
                           x\^a\ r\^b\ \(\(L\_p\%n\)(r)\)\ \(\(L\_q\%n\)(
                               x)\)\ \(\(L\_i\%m\)(r)\)\ \(\(L\_j\%m\)(
                               x)\)], {x\^\(_ : 1\)\ r\^\(_ : 1\)},
                         Simplify] /. \[InvisibleSpace]c_. \ x\^\(a + \[Eta]_. \
\)\ r\^\(b + l_. \) \[RuleDelayed]
                       c\ \(\(\[ScriptCapitalI]\_\(l, \[Eta], m,
                               n\)\)(\[Xi])\)]]\)\)\)\)\)], "Input",
   InitializationCell->True],

Cell["where", "Text"],

Cell[BoxData[
     \(TraditionalForm\`\[ScriptCapitalI] /: \[ScriptCapitalI]\_\(l_, \[Eta]_, \
m_, n_\) :=
       Function[{\[Xi]}, \[Xi]\^\(2\ \[Eta]\)\ \((1 + \[Xi]\^2)\)\^\(\(-l\) - \
\[Eta]\)\ \(\[CapitalGamma](m + n + l + \[Eta] + 3\/2)\)]\)], "Input",
   InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{

   CounterBox["Section"],
   ".",

   CounterBox["Subsection"],
   ". Total Energy Calculation"
}], "Subsection"],

Cell["The total energy of the quantum dot system is given by", "Text"],

Cell[BoxData[
     FormBox[
       RowBox[{\(\[ScriptCapitalE][\[ScriptCapitalS]_, \[ScriptCapitalN]_,
           k_, \[Eta]_]\), ":=",
         RowBox[{\(\[ScriptCapitalE][\[ScriptCapitalS], \[ScriptCapitalN],
             k, \[Eta]]\), "=",

           RowBox[{\(\[Sum]\+\(\[Lambda] = 1\)\%\(Length[\[ScriptCapitalS]]\)\
\[ScriptCapitalE]\_\(\[ScriptCapitalS]\[LeftDoubleBracket]\[Lambda]\
\[RightDoubleBracket], \[Eta]\)\), "-",
             RowBox[{\(1\/2\), " ",

               RowBox[{\(\[Sum]\+\(\[Lambda] =
                       1\)\%\(Length[\[ScriptCapitalS]]\)\),
                 RowBox[{\(\[Sum]\+\(\[Mu] = 1\)\%\(\[Lambda] - 1\)\),
                   RowBox[{\(\[Sum]\+\(i = 1\)\%\[ScriptCapitalN]\),
                     RowBox[{\(\[Sum]\+\(j = 1\)\%\[ScriptCapitalN]\),
                       RowBox[{\(\[Sum]\+\(p = 1\)\%\[ScriptCapitalN]\),
                         RowBox[{\(\[Sum]\+\(q = 1\)\%\[ScriptCapitalN]\),

                           RowBox[{\(c\_\(\[ScriptCapitalS]\[LeftDoubleBracket]\
\[Lambda]\[RightDoubleBracket], \[Eta]\)\[LeftDoubleBracket]
                               i\[RightDoubleBracket]\),
                             " ", \(c\_\(\[ScriptCapitalS]\[LeftDoubleBracket]\
\[Lambda]\[RightDoubleBracket], \[Eta]\)\[LeftDoubleBracket]
                               j\[RightDoubleBracket]\),
                             " ", \(c\_\(\[ScriptCapitalS]\[LeftDoubleBracket]\
\[Mu]\[RightDoubleBracket], \[Eta]\)\[LeftDoubleBracket]
                               p\[RightDoubleBracket]\),
                             " ", \(c\_\(\[ScriptCapitalS]\[LeftDoubleBracket]\
\[Mu]\[RightDoubleBracket], \[Eta]\)\[LeftDoubleBracket]
                               q\[RightDoubleBracket]\), "  ",
                             RowBox[{"(",

                               RowBox[{\(k\^\(\(-\[LeftBracketingBar]\
\[ScriptCapitalS]\[LeftDoubleBracket]\[Lambda], 2\[RightDoubleBracket]\
\[RightBracketingBar]\) - \[LeftBracketingBar]\[ScriptCapitalS]\
\[LeftDoubleBracket]\[Mu], 2\[RightDoubleBracket]\[RightBracketingBar] - 3\/2\
\)\ \[GothicD][{i - 1, j -
                                         1, \[LeftBracketingBar]\
\[ScriptCapitalS]\[LeftDoubleBracket]\[Lambda],
                                         2\[RightDoubleBracket]\
\[RightBracketingBar]}, {p - 1, q -
                                         1, \[LeftBracketingBar]\
\[ScriptCapitalS]\[LeftDoubleBracket]\[Mu],
                                         2\[RightDoubleBracket]\
\[RightBracketingBar]}]\), "-",
                                 RowBox[{
                                   SubscriptBox[
                                     InterpretationBox["\[Delta]",
                                       KroneckerDelta,
                                       Editable->False,

                                       Selectable->
                                         False], \(\[ScriptCapitalS]\
\[LeftDoubleBracket]\[Lambda],
                                       3\[RightDoubleBracket], \
\[ScriptCapitalS]\[LeftDoubleBracket]\[Mu], 3\[RightDoubleBracket]\)],
                                   " ", \(k\^\(\(-\[LeftBracketingBar]\
\[ScriptCapitalS]\[LeftDoubleBracket]\[Lambda],
                                         2\[RightDoubleBracket]\
\[RightBracketingBar]\) - \[LeftBracketingBar]\[ScriptCapitalS]\
\[LeftDoubleBracket]\[Mu], 2\[RightDoubleBracket]\[RightBracketingBar] -
                                         3\/2\)\),
                                   " ", \(\[GothicF][{i - 1,
                                       j - 1, \[ScriptCapitalS]\
\[LeftDoubleBracket]\[Lambda], 2\[RightDoubleBracket]}, {p - 1,
                                       q - 1, \[ScriptCapitalS]\
\[LeftDoubleBracket]\[Mu], 2\[RightDoubleBracket]}]\)}]}],
                               ")"}]}]}]}]}]}]}]}]}]}]}]}],
       TraditionalForm]], "Input",
   InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{

   CounterBox["Section"],
   ".",

   CounterBox["Subsection"],
   ". Hartree-Fock Evaluation"
}], "Subsection",
   CellTags->"Subsection: Hartree-Fock Evaluation"],

Cell[TextData[{
   "The module ",
   StyleBox["HartreeFock",
     FontWeight->"Bold"],
   " is the main program body for running the Hartree-Fock calculation to \
solve for ",
   StyleBox["N",
     FontSlant->"Italic"],
   " electrons defined by the state list \[ScriptCapitalS] with a matrix \
(expansion) size \[ScriptCapitalN]. Self-consistency is obtained by setting \
up a while loop which runs until the energy difference between two \
consecutive iterations is less than \[Delta]. The parameters ",
   StyleBox["k",
     FontSlant->"Italic"],
   " and ",
   Cell[BoxData[
       \(TraditionalForm\`V\_0\)]],
   " define the confining potential (e.g. the harmonic confining potential of \
the form ",
   Cell[BoxData[
       \(TraditionalForm\`V(r) = \(-V\_0\) + \(1\/2\) \(k\^2\) r\^2\)]],
   ")."
}], "Text"],

Cell[BoxData[
     \(TraditionalForm\`HartreeFock[\[ScriptCapitalS]_, \[ScriptCapitalN]_, \
\[Delta]_, k_, V0_] :=
       Module[{\[ScriptCapitalD] = 2\ \[Delta], \[Eta] = 0, \[Tau]1 =
             0, \[Tau]2 = 0}, \[IndentingNewLine]\[Tau]1 =
           First[Timing[\[IndentingNewLine]\(InitialiseMatrixElements[\
\[ScriptCapitalN]];\)]]; \[IndentingNewLine]\[Tau]2 =
           First[Timing[\[IndentingNewLine]InitialiseCoefficients[\
\[ScriptCapitalS], \[ScriptCapitalN],
                 k]; \[IndentingNewLine]StateSolve[\[ScriptCapitalS], \
\[ScriptCapitalN], k, V0, \[Eta]]; \[IndentingNewLine]While[
                 Abs[\[ScriptCapitalD]] > \[Delta], \
\[IndentingNewLine]\(\[Eta]++\); \[IndentingNewLine]StateSolve[\
\[ScriptCapitalS], \[ScriptCapitalN], k,
                   V0, \[Eta]]; \[IndentingNewLine]\[ScriptCapitalD] = \
\[ScriptCapitalE][\[ScriptCapitalS], \[ScriptCapitalN],
                       k, \[Eta] +
                         1] - \[ScriptCapitalE][\[ScriptCapitalS], \
\[ScriptCapitalN],
                       k, \[Eta]]\[IndentingNewLine]]\[IndentingNewLine]]]; \
\[IndentingNewLine]SaveIntegrals; \[IndentingNewLine]PrintOutput[\
\[ScriptCapitalS], \[ScriptCapitalD], \[Eta]]; \
\[IndentingNewLine]Print["\<Initialisation Time = \>", \[Tau]1]; \
\[IndentingNewLine]Print["\<Running Time = \>", \
\[Tau]2]\[IndentingNewLine]]\)], "Input",
   InitializationCell->True],

Cell[TextData[{
   "The first step above, ",
   StyleBox["InitialiseMatrixElements",
     FontWeight->"Bold"],
   " is used to help save time with future calculations. All the ",
   StyleBox["AngleBracket",
     FontWeight->"Bold"],
   " function definitions (",
   StyleBox["ie",
     FontSlant->"Italic"],
   ", ",
   Cell[BoxData[
       \(TraditionalForm\`\[LeftAngleBracket]{i, j}, {p, q},
         1\[RightAngleBracket]\)]],
   " and ",
   Cell[BoxData[
       \(TraditionalForm\`\[LeftAngleBracket]{i, j}, {p, q},
         2\[RightAngleBracket]\)]],
   ") required for an ",
   Cell[BoxData[
       \(TraditionalForm\`\[ScriptCapitalN]\[Times]\[ScriptCapitalN]\)]],
   " matrix expansion are saved in a file called ",
   StyleBox["matrix",
     FontSlant->"Italic"],
   "\[ScriptCapitalN]",
   StyleBox[".mx",
     FontSlant->"Italic"],
   " in a subdirectory of the home directory called ",
   StyleBox["HFData",
     FontSlant->"Italic"],
   ". This module creates the file and subdirectory if they do not already \
exist, and loads the file otherwise. It also loads values for the integrals \
\[GothicD] and \[GothicF] if they have been saved in the files ",
   StyleBox["d.mx",
     FontSlant->"Italic"],
   " and ",
   StyleBox["f.mx",
     FontSlant->"Italic"],
   "."
}], "Text"],

Cell[BoxData[
     \(TraditionalForm\`InitialiseMatrixElements[\[ScriptCapitalN]_] :=
       Module[{}, \[IndentingNewLine]SetDirectory[$HomeDirectory]; \
\[IndentingNewLine]If[FileNames["\<HFData\>"] == {},
           CreateDirectory["\<HFData\>"]]; \[IndentingNewLine]If[
           FileNames[
               ToFileName["\<HFData\>", "\<matrix\>" <>
                   ToString[\[ScriptCapitalN]] <> "\<.mx\>"]] == {}, \
\[IndentingNewLine]Table[\[LeftAngleBracket]{i, j}, {p, q},
               1\[RightAngleBracket], {i, 0, \[ScriptCapitalN] - 1}, {j,
               0, \[ScriptCapitalN] - 1}, {p, 0, \[ScriptCapitalN] - 1}, {q,
               0, \[ScriptCapitalN] -
                 1}]; \[IndentingNewLine]Table[\[LeftAngleBracket]{i, j}, {p,
                 q}, 2\[RightAngleBracket], {i, 0, \[ScriptCapitalN] - 1}, {j,
               0, \[ScriptCapitalN] - 1}, {p, 0, \[ScriptCapitalN] - 1}, {q,
               0, \[ScriptCapitalN] - 1}]; \[IndentingNewLine]DumpSave[
             ToFileName["\<HFData\>", "\<matrix\>" <>
                 ToString[\[ScriptCapitalN]] <> "\<.mx\>"],
             AngleBracket], \[IndentingNewLine]Get[
             ToFileName["\<HFData\>", "\<matrix\>" <>
                 ToString[\[ScriptCapitalN]] <> "\<.mx\>"]]]; \
\[IndentingNewLine]If[
           FileNames[
               ToFileName["\<HFData\>", "\<d.mx\>"]] \[NotEqual] {}, \
\[IndentingNewLine]Get[
             ToFileName["\<HFData\>", "\<d.mx\>"]]]; \[IndentingNewLine]If[
           FileNames[
               ToFileName["\<HFData\>", "\<f.mx\>"]] \[NotEqual] {}, \
\[IndentingNewLine]Get[
             ToFileName["\<HFData\>", "\<f.mx\>"]]]\[IndentingNewLine]]\)], \
"Input",
   InitializationCell->True],

Cell[TextData[{
   StyleBox["InitialiseCoefficients",
     FontWeight->"Bold"],
   " assigns initial values to the expansion coefficients, and uses ",
   StyleBox["NormaliseCoefficients",
     FontWeight->"Bold"],
   " to normalise them so",
   " that ",
   Cell[BoxData[
       FormBox[
         RowBox[{
           RowBox[{
             SuperscriptBox[
               StyleBox["c",
                 FontWeight->"Bold"], "\[Dagger]"], " ",
             StyleBox["\[ScriptCapitalB]",
               FontWeight->"Bold"], " ",
             StyleBox["c",
               FontWeight->"Bold"]}], "=", "1"}], TraditionalForm]]],
   "."
}], "Text"],

Cell[BoxData[
     FormBox[
       RowBox[{\(InitialiseCoefficients[\[ScriptCapitalS]_, \
\[ScriptCapitalN]_, k_]\), ":=",
         RowBox[{"Module", "[",
           RowBox[{\({\[Chi], m, n}\), ",", "\[IndentingNewLine]",

             RowBox[{\(\[Chi] = Table[0, {j, \[ScriptCapitalN]}]\), ";",
               "\[IndentingNewLine]",
               RowBox[{"Do", "[",
                 RowBox[{
                   RowBox[{
                     RowBox[{"n", "=",

                       FormBox[\(\(\[ScriptCapitalS]\[LeftDoubleBracket]
                             i\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\),
                         "TraditionalForm"]}], ";",
                     RowBox[{"m", "=",

                       FormBox[\(\(\[ScriptCapitalS]\[LeftDoubleBracket]
                             i\[RightDoubleBracket]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket]\),
                         "TraditionalForm"]}], ";", "\[IndentingNewLine]",
                     RowBox[{"c", "/:",
                       SubscriptBox["c",
                         RowBox[{

                           FormBox[\(\[ScriptCapitalS]\[LeftDoubleBracket]
                               i\[RightDoubleBracket]\),
                             "TraditionalForm"], ",", "0"}]], "=",
                       RowBox[{"NormaliseCoefficients", "[",
                         RowBox[{
                           RowBox[{"ReplacePart", "[",
                             RowBox[{
                               FormBox["\[Chi]",
                                 "TraditionalForm"], ",", "1", ",",
                               RowBox[{
                                 FormBox["n",
                                   "TraditionalForm"], "+", "1"}]}], "]"}],
                           ",", "k", ",", "m"}], "]"}]}], ";"}],
                   "\[IndentingNewLine]",
                   ",", \({i, Length[\[ScriptCapitalS]]}\)}], "]"}]}]}],
           "\[IndentingNewLine]", "]"}]}], TraditionalForm]], "Input",
   InitializationCell->True],

Cell[BoxData[
     \(TraditionalForm\`\(NormaliseCoefficients[c_List, k_, m_] :=
         c\/\@\(c . \[ScriptCapitalB]\_\(Length[c]\)[k, m] . 
c\);\)\)], "Input",\

   InitializationCell->True],

Cell[TextData[{
   StyleBox["StateSolve",
     FontWeight->"Bold"],
   " solves for each electron in the system, and then defines a new set of \
normalised coefficients based on the solutions."
}], "Text"],

Cell[BoxData[
     FormBox[
       RowBox[{\(StateSolve[\[ScriptCapitalS]_, \[ScriptCapitalN]_, k_,
           V0_, \[Eta]_]\), ":=",
         RowBox[{"Module", "[",

           RowBox[{\({\[Lambda], \[CurlyEpsilon], \[Chi]}\), ",",
             "\[IndentingNewLine]",
             RowBox[{"Do", "[",
               RowBox[{
                 RowBox[{
                   RowBox[{"\[Lambda]", "=",

                     FormBox[\(\[ScriptCapitalS]\[LeftDoubleBracket]
                         i\[RightDoubleBracket]\),
                       "TraditionalForm"]}], ";", "\[IndentingNewLine]",
                   RowBox[{\({\[CurlyEpsilon], \[Chi]}\), "=",
                     RowBox[{"Transpose", "[",
                       RowBox[{"Select", "[",
                         RowBox[{
                           SuperscriptBox[
                             RowBox[{"(",
                               RowBox[{"Chop", "[",
                                 RowBox[{"Eigensystem", "[",
                                   RowBox[{
                                     RowBox[{

                                       SuperscriptBox[\((\[ScriptCapitalB]\_\
\[ScriptCapitalN][k, \[Lambda]\[LeftDoubleBracket]2\[RightDoubleBracket]])\),

                                         TagBox[\(-1\),
                                         Inverse]],
                                       ".", \(\[ScriptCapitalA]\_\
\[ScriptCapitalN][\[Lambda], \[ScriptCapitalS], k, V0, \[Eta]]\)}], "//",
                                     "N"}], "]"}], "]"}], ")"}], "T"],
                           ",", \(First[#1] < 0 &\)}], "]"}], "]"}]}], ";",
                   "\[IndentingNewLine]", \(c /:
                     c\_\(\[Lambda], \[Eta] + 1\) =
                     Part[\(NormaliseCoefficients[#1,
                             k, \[Lambda]\[LeftDoubleBracket]2\
\[RightDoubleBracket]] &\) /@ \[Chi], \[Lambda]\[LeftDoubleBracket]1\
\[RightDoubleBracket] + 1]\), ";", "\[IndentingNewLine]",
                   RowBox[{
                   "\[ScriptCapitalE]",
                     "/:", \(\[ScriptCapitalE]\_\(\[Lambda], \[Eta] + 1\)\),
                     "=",

                     FormBox[\(\[CurlyEpsilon]\[LeftDoubleBracket]\[Lambda]\
\[LeftDoubleBracket]1\[RightDoubleBracket] + 1\[RightDoubleBracket]\),
                       "TraditionalForm"]}], ";"}], "\[IndentingNewLine]",
                 ",", \({i, Length[\[ScriptCapitalS]]}\)}], "]"}]}],
           "\[IndentingNewLine]", "]"}]}], TraditionalForm]], "Input",
   InitializationCell->True],

Cell[TextData[{
   "Upon exiting the self-consistency loop, we save the values for the \
\[GothicD] and \[GothicF] integrals using the ",
   StyleBox["SaveIntegrals",
     FontWeight->"Bold"],
   " module (they are saved to the files ",
   StyleBox["d.mx",
     FontSlant->"Italic"],
   " and ",
   StyleBox["f.mx",
     FontSlant->"Italic"],
   " in the ",
   StyleBox["HFData",
     FontSlant->"Italic"],
   " subdirectory of the home directory). This is done to increase efficiency \
in further calculations, since it is not necessary to reevaluate these time \
consuming integrals."
}], "Text"],

Cell[BoxData[
     \(TraditionalForm\`SaveIntegrals :=
       Module[{}, \[IndentingNewLine]DumpSave[
           ToFileName["\<HFData\>", "\<d.mx\>"], \[GothicD]]; \
\[IndentingNewLine]DumpSave[
           ToFileName["\<HFData\>", "\<f.mx\>"], \[GothicF]]; \
\[IndentingNewLine]ResetDirectory[];\[IndentingNewLine]]\)], "Input",
   InitializationCell->True],

Cell[TextData[{
   StyleBox["PrintOutput",
     FontWeight->"Bold"],
   " is a module which should be modified by the user depending upon the \
desired output. In this example, the calculated energies (converted to meV) \
are saved under the symbol \[GothicCapitalE], and the expansion coefficients \
under the symbol \[GothicCapitalC]. The total energy, number of iterations, \
and the energy difference between the last two iterations are printed out. By \
default, the conversion factors are those of GaAs, which has an effective \
mass ",
   Cell[BoxData[
       \(TraditionalForm\`\(m\^*\) = 0.065\ m\_e\)]],
   " and dielectric constant ",
   Cell[BoxData[
       FormBox[
         RowBox[{"\[Epsilon]", "=",
           RowBox[{"12.9",
             SubscriptBox[
               StyleBox["\[Epsilon]",
                 FontWeight->"Bold"], "0"]}]}], TraditionalForm]]],
   "."
}], "Text"],

Cell[BoxData[
     \(TraditionalForm\`PrintOutput[\[ScriptCapitalS]_, \[ScriptCapitalD]_, \
\[Eta]_] :=
       Module[{Hartree = 27.2116, \[Epsilon] = 12.9, \[ScriptM] =
             0.065}, \[IndentingNewLine]Do[\[GothicCapitalE] /: \
\[GothicCapitalE]\_\(Length[\[ScriptCapitalS]], \[ScriptCapitalS][\([i]\)]\) \
= 1000 \( \[ScriptM]\ Hartree\)\/\[Epsilon]\^2\ \[ScriptCapitalE]\_\(\
\[ScriptCapitalS][\([i]\)], \[Eta] + 1\); \
\[IndentingNewLine]\[GothicCapitalC] /: \[GothicCapitalC]\_\(Length[\
\[ScriptCapitalS]], \[ScriptCapitalS][\([i]\)]\) =
             c\_\(\[ScriptCapitalS][\([i]\)], \[Eta] + 1\), \
\[IndentingNewLine]{i,
             Length[\[ScriptCapitalS]]}]; \[IndentingNewLine]\[GothicCapitalE] \
/: \[GothicCapitalE]\_\(Length[\[ScriptCapitalS]]\) =
           1000 \( \[ScriptM]\ Hartree\)\/\[Epsilon]\^2\ \ \[ScriptCapitalE][\
\[ScriptCapitalS], \[ScriptCapitalN],
               k, \[Eta] +
                 1]; \[IndentingNewLine]Print["\<Total Energy = \>", \ \
\[GothicCapitalE]\_\(Length[\[ScriptCapitalS]]\), \ "\< meV\>"]; \
\[IndentingNewLine]Print["\<Number of Iterations = \>", \ \[Eta] +
             1]; \[IndentingNewLine]Print["\<Convergence = \>", \ \
\[ScriptCapitalD]]\[IndentingNewLine]]\)], "Input",
   InitializationCell->True],

Cell["\<\
To give an idea of the time required for the calculations, the \
initialisation time and the time required to complete the Hartree-Fock \
self-consistency loop are also printed out.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{

   CounterBox["Section"],
   ". Example"
}], "Section",
   FontFamily->"Times"],

Cell[TextData[{
   "The first step is to load in the package. This can be done either by \
opening the ",
   StyleBox["QDHartreeFock.nb",
     FontWeight->"Bold"],
   " file and evaluating the initialisation cells (using the menu: ",
   StyleBox["Kernel",
     FontSlant->"Italic"],
   " \[VerticalSeparator] ",
   StyleBox["Evaluation",
     FontSlant->"Italic"],
   " \[VerticalSeparator] ",
   StyleBox["Evaluate",
     FontSlant->"Italic"],
   " ",
   StyleBox["Initialisation",
     FontSlant->"Italic"],
   "), or by loading in the ",
   StyleBox["QDHartreeFock.m",
     FontWeight->"Bold"],
   " package. The latter can be done by first saving the package in the ",
   StyleBox["ExtraPackages",
     FontSlant->"Italic"],
   " directory in the ",
   StyleBox["Mathematica",
     FontSlant->"Italic"],
   " folder, and then using ",
   StyleBox["<<",
     FontWeight->"Bold"],
   ". For example,"
}], "Text"],

Cell[BoxData[
     \(TraditionalForm\`<< QDHartreeFock`\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[{

   CounterBox["Section"],
   ".",

   CounterBox["Subsection"],
   ". Quantum dots with 2 and 3\[Dash]electrons"
}], "Subsection"],

Cell[TextData[{
   "We now assign values to the parameters ",
   StyleBox["k",
     FontSlant->"Italic"],
   " and ",
   Cell[BoxData[
       \(TraditionalForm\`V\_0\)]],
   "in the harmonic confining potential of the form ",
   Cell[BoxData[
       \(TraditionalForm\`V(r) = \(-V\_0\) + 1\/2\ k\^2\ r\^2\)]],
   ", say ",
   Cell[BoxData[
       \(TraditionalForm\`k = 10\)]],
   " and ",
   Cell[BoxData[
       \(TraditionalForm\`V\_0 = 100\)]],
   "."
}], "Text"],

Cell[BoxData[
     \(TraditionalForm\`k = 10.0; V\_0 = 100.0;\)], "Input"],

Cell[TextData[{
   "Consider the lowest energy states of the 2\[Dash]electron  and \
3\[Dash]electron systems, ",
   StyleBox["\[ScriptCapitalS]2",
     FontWeight->"Bold"],
   " and ",
   StyleBox["\[ScriptCapitalS]3",
     FontWeight->"Bold"],
   " are defined by listing the states ",
   Cell[BoxData[
       \(TraditionalForm\`{n, m, m\_s}\)]],
   " of each electron,"
}], "Text"],

Cell[BoxData[
     \(TraditionalForm\`\(\[ScriptCapitalS]2 = {{0, 0, 1\/2}, {0,
             0, \(-\(1\/2\)\)}};\)\)], "Input"],

Cell[BoxData[
     \(TraditionalForm\`\(\[ScriptCapitalS]3 = {{0, 0, 1\/2}, {0,
             0, \(-\(1\/2\)\)}, {0, 1, 1\/2}};\)\)], "Input"],

Cell[TextData[{
   "With the physical problem set up, we set the parameters which determine \
the accuracy of the calculation. We choose a matrix (expansion) size of, say \
",
   Cell[BoxData[
       \(TraditionalForm\`\[ScriptCapitalN] = 4\)]],
   ", and a value for \[Delta], the energy difference between the last two \
iterations, say ",
   Cell[BoxData[
       \(TraditionalForm\`\[Delta] = 10\^\(-7\)\)]],
   "."
}], "Text"],

Cell[BoxData[
     \(TraditionalForm\`\[ScriptCapitalN] = 4; \[Delta] =
       10\^\(-7\);\)], "Input"],

Cell["\<\
We can now run the Hartree-Fock calculations. For the \
3\[Dash]electron system,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
     \(TraditionalForm\`HartreeFock[\[ScriptCapitalS]3, \[ScriptCapitalN], \
\[Delta], k, V\_0]\)], "Input"],

Cell[BoxData[
     FormBox[
       InterpretationBox[\("Total Energy = \
"\[InvisibleSpace]\(-2673.07224752127`\)\[InvisibleSpace]" meV"\),
         SequenceForm[ "Total Energy = ", -2673.0722475212701, " meV"],
         Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
     FormBox[
       InterpretationBox[\("Number of Iterations = "\[InvisibleSpace]9\),
         SequenceForm[ "Number of Iterations = ", 9],
         Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
     FormBox[
       InterpretationBox[\("Convergence = \
"\[InvisibleSpace]7.888544928391639`*^-8\),
         SequenceForm[ "Convergence = ", 7.8885449283916387*^-08],
         Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
     FormBox[
       InterpretationBox[\("Initialisation Time = "\[InvisibleSpace]\(142.3`\ \
Second\)\),
         SequenceForm[ "Initialisation Time = ",
           Times[ 142.30000000000001, Second]],
         Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
     FormBox[
       InterpretationBox[\("Running Time = \
"\[InvisibleSpace]\(289.0833333333333`\ Second\)\),
         SequenceForm[ "Running Time = ",
           Times[ 289.08333333333331, Second]],
         Editable->False], TraditionalForm]], "Print"]
}, Closed]],

Cell["For the 2\[Dash]electron system,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
     \(TraditionalForm\`HartreeFock[\[ScriptCapitalS]2, \[ScriptCapitalN], \
\[Delta], k, V\_0]\)], "Input"],

Cell[BoxData[
     FormBox[
       InterpretationBox[\("Total Energy = \
"\[InvisibleSpace]\(-1872.1471531634736`\)\[InvisibleSpace]" meV"\),
         SequenceForm[ "Total Energy = ", -1872.1471531634736, " meV"],
         Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
     FormBox[
       InterpretationBox[\("Number of Iterations = "\[InvisibleSpace]9\),
         SequenceForm[ "Number of Iterations = ", 9],
         Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
     FormBox[
       InterpretationBox[\("Convergence = \
"\[InvisibleSpace]1.8604765728014172`*^-8\),
         SequenceForm[ "Convergence = ", 1.8604765728014172*^-08],
         Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
     FormBox[
       InterpretationBox[\("Initialisation Time = \
"\[InvisibleSpace]\(1.6562719999999445`\ Second\)\),
         SequenceForm[ "Initialisation Time = ",
           Times[ 1.6562719999999445, Second]],
         Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
     FormBox[
       InterpretationBox[\("Running Time = \
"\[InvisibleSpace]\(2.6999999999999886`\ Second\)\),
         SequenceForm[ "Running Time = ",
           Times[ 2.6999999999999886, Second]],
         Editable->False], TraditionalForm]], "Print"]
}, Closed]],

Cell[TextData[{
   "Notice the significant time saving in both the initialisation time and the \
running time for the solution of the ",
   StyleBox["\[ScriptCapitalS]2",
     FontWeight->"Bold"],
   " state once the ",
   StyleBox["\[ScriptCapitalS]3",
     FontWeight->"Bold"],
   " state has been solved for. This is due to the fact that many of the time \
consuming aspects of the code are saved after the first time ",
   StyleBox["HartreeFock",
     FontWeight->"Bold"],
   " is run."
}], "Text"],

Cell[TextData[{
   "Implementation of this procedure was performed with ",
   StyleBox["Mathematica ",
     FontSlant->"Italic"],
   "version 4.1, running remotely",
   StyleBox[" ",
     FontSlant->"Italic"],
   "from a DEC Alpha workstation 500 with 0.5GB RAM. Convergence was \
obtainable, with \[Delta] becoming less than ",
   Cell[BoxData[
       \(TraditionalForm\`10\^\(-7\)\)]],
   " for anywhere between 4 and 20 iterations depending on the number of \
electrons in the system."
}], "Text"],

Cell[TextData[{
   "Calculations were performed for quantum dots with up to ",
   Cell[BoxData[
       \(TraditionalForm\`N = 18\)]],
   " electrons. As would be expected, calculation time increased with each \
extra electron, markedly so when jumping to a higher energy level. The \
program is limited in that calculations with matrix (expansion) sizes larger \
than ",
   Cell[BoxData[
       \(TraditionalForm\`\[ScriptCapitalN] = 4\)]],
   " become laborious due to increased running times and CPU load. This \
limitation on the expansion means a deficiency in the accuracy of the \
calculations, especially as the electron number increases. It also means that \
calculations with non-harmonic confining potentials are not feasible for more \
than one electron with the present code. The limitation is caused by the time \
required to calculate the \[GothicD] and \[GothicF] terms. The conversion to \
a more numerically oriented code and language, such as Fortran or C will \
speed up computation immensely."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{

   CounterBox["Section"],
   ".",

   CounterBox["Subsection"],
   ". Gaussian confining potential"
}], "Subsection"],

Cell[TextData[{
   "Although in its present from, this code is not suitable for calculations \
for ",
   StyleBox["N",
     FontSlant->"Italic"],
   "-electron quantum dots with confining potentials other than harmonic, it \
is still fine for single electron calculations. A solution was found for the \
confining potential integrals when the confining potential is a gaussian \
function of the form ",
   Cell[BoxData[
       \(TraditionalForm\`V(
           r) = \(-V\_0\) \[ExponentialE]\^\(\(-r\^2\)/R\^2\)\)]],
   ", where ",
   StyleBox["R",
     FontSlant->"Italic"],
   " is related to ",
   StyleBox["k",
     FontSlant->"Italic"],
   " in the basis functions by ",
   Cell[BoxData[
       \(TraditionalForm\`R = \@\(2  V\_0/k\^2\)\)]],
   ". The solution is"
}], "Text"],

Cell[BoxData[
     \(TraditionalForm\`Clear[\[ScriptCapitalV]]\)], "Input"],

Cell[BoxData[
     FormBox[
       RowBox[{
       "\[ScriptCapitalV]", "/:", \(\[ScriptCapitalV]\_\(i_, j_\)\), ":=",
         RowBox[{
         "\[ScriptCapitalV]", "/:", \(\[ScriptCapitalV]\_\(i, j\)\), "=",
           RowBox[{
           "\[ScriptCapitalV]", "/:", \(\[ScriptCapitalV]\_\(j, i\)\), "=",
             RowBox[{"Function", "[",
               RowBox[{\({k, V0, m}\), ",",

                 RowBox[{\(-\(\(\(2\^m\)
                           V0\^\(m + 2\)\)\/\(\(k\^\(2 \((m +
                                   1)\)\)\)\(\ \)\)\)\),
                   " ", \(\(\(\((i + m)\)!\)\ \(\((j +
                               m)\)!\)\)\/\(\(i!\)\ \(j!\)\ \(m!\)\)\), \(\((1 \
+ \(2  V0\)\/k)\)\^\(\(-i\) - j - m - 1\)\), "  ",
                   TagBox[
                     TagBox[
                       RowBox[{
                         RowBox[{
                           SubscriptBox["\[InvisiblePrefixScriptBase]",
                             FormBox["2",
                               "TraditionalForm"]],
                           SubscriptBox["F",
                             FormBox["1",
                               "TraditionalForm"]]}],
                         "\[InvisibleApplication]",
                         RowBox[{"(",
                           RowBox[{
                             TagBox[
                               TagBox[
                                 RowBox[{
                                   TagBox[\(-i\),
                                     Hypergeometric2F1,
                                     Editable->True], ",",
                                   TagBox[\(-j\),
                                     Hypergeometric2F1,
                                     Editable->True]}],
                                 InterpretTemplate[ {
                                   SlotSequence[ 1]}&]],
                               Hypergeometric2F1,
                               Editable->False], ";",
                             TagBox[
                               TagBox[
                                 TagBox[\(m + 1\),
                                   Hypergeometric2F1,
                                   Editable->True],
                                 InterpretTemplate[ {
                                   SlotSequence[ 1]}&]],
                               Hypergeometric2F1,
                               Editable->False], ";",
                             TagBox[\(\(4\ V0\^2\)\/k\^2\),
                               Hypergeometric2F1,
                               Editable->True]}], ")"}]}],
                       InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                       Editable->False],
                     Hypergeometric2F1]}]}], "]"}]}]}]}],
       TraditionalForm]], "Input"],

Cell["(Note: these are not flagged as initialisation cells.)", "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{913, 609},
WindowMargins->{{5, Automatic}, {Automatic, 6}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[",
         RowBox[ {
           TagBox[
           "\[Placeholder]", NotationBoxTag, TagStyle ->
             "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",

           TagBox[
           "\[Placeholder]", NotationBoxTag, TagStyle ->
             "NotationTemplateStyle"]}], "]"}],
     "notation>"->RowBox[ {"Notation", "[",
         RowBox[ {
           TagBox[
           "\[Placeholder]", NotationBoxTag, TagStyle ->
             "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ",
           TagBox[
           "\[Placeholder]", NotationBoxTag, TagStyle ->
             "NotationTemplateStyle"]}], "]"}],
     "notation<"->RowBox[ {"Notation", "[",
         RowBox[ {
           TagBox[
           "\[Placeholder]", NotationBoxTag, TagStyle ->
             "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ",
           TagBox[
           "\[Placeholder]", NotationBoxTag, TagStyle ->
             "NotationTemplateStyle"]}], "]"}],
     "symb"->RowBox[ {"Symbolize", "[",
         TagBox[
         "\[Placeholder]", NotationBoxTag, TagStyle ->
           "NotationTemplateStyle"], "]"}],
     "infixnotation"->RowBox[ {"InfixNotation", "[",
         RowBox[ {
           TagBox[
           "\[Placeholder]", NotationBoxTag, TagStyle ->
             "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}],
     "addia"->RowBox[ {"AddInputAlias", "[",
         RowBox[ {
           TagBox[
           "\[Placeholder]", NotationBoxTag, TagStyle ->
             "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}],
     "pattwraper"->TagBox[
       "\[Placeholder]", NotationPatternTag, TagStyle ->
         "NotationPatternWrapperStyle"],
     "madeboxeswraper"->TagBox[
       "\[Placeholder]", NotationMadeBoxesTag, TagStyle ->
         "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{

   Cell[CellGroupData[{
   Cell["Style Definitions", "Subtitle"],

   Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

   Cell[CellGroupData[{

   Cell["Style Environment Names", "Section"],

   Cell[StyleData[All, "Working"],
     PageWidth->WindowWidth,
     CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
     ScriptMinSize->9],

   Cell[StyleData[All, "Presentation"],
     PageWidth->WindowWidth,
     CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
     ScriptMinSize->12],

   Cell[StyleData[All, "Condensed"],
     PageWidth->WindowWidth,
     CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
     ScriptMinSize->8],

   Cell[StyleData[All, "Printout"],
     PageWidth->PaperWidth,
     CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
     ScriptMinSize->5,
     PrivateFontOptions->{"FontType"->"Outline"}]
   }, Closed]],

   Cell[CellGroupData[{

   Cell["Notebook Options", "Section"],

   Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

   Cell[StyleData["Notebook"],
     PageHeaders->{{Cell[
             TextData[ {
               CounterBox[ "Page"]}], "PageNumber"], None, Cell[
             TextData[ {
               ValueBox[ "FileName"]}], "Header"]}, {Cell[
             TextData[ {
               ValueBox[ "FileName"]}], "Header"], None, Cell[
             TextData[ {
               CounterBox[ "Page"]}], "PageNumber"]}},
     CellFrameLabelMargins->6,
     StyleMenuListing->None]
   }, Closed]],

   Cell[CellGroupData[{

   Cell["Styles for Headings", "Section"],

   Cell[CellGroupData[{

   Cell[StyleData["Title"],
     CellMargins->{{12, Inherited}, {20, 40}},
     CellGroupingRules->{"TitleGrouping", 0},
     PageBreakBelow->False,
     DefaultNewInlineCellStyle->"None",
     InputAutoReplacements->{"TeX"->StyleBox[
             RowBox[ {"T",
               AdjustmentBox[
               "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]],
         "LaTeX"->StyleBox[
             RowBox[ {"L",
               StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001],
                 FontSize -> Smaller], "T",
               AdjustmentBox[
               "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]],
         "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica",
         Inherited},
     LineSpacing->{1, 11},
     LanguageCategory->"NaturalLanguage",
     CounterIncrements->"Title",
     CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
         "Subtitle", 0}, {"Subsubtitle", 0}},
     FontFamily->"Helvetica",
     FontSize->36,
     FontWeight->"Bold"],

   Cell[StyleData["Title", "Presentation"],
     CellMargins->{{24, 10}, {20, 40}},
     LineSpacing->{1, 0},
     FontSize->44],

   Cell[StyleData["Title", "Condensed"],
     CellMargins->{{8, 10}, {4, 8}},
     FontSize->20],

   Cell[StyleData["Title", "Printout"],
     CellMargins->{{2, 10}, {12, 30}},
     FontSize->24]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["Subtitle"],
     CellMargins->{{12, Inherited}, {20, 15}},
     CellGroupingRules->{"TitleGrouping", 10},
     PageBreakBelow->False,
     DefaultNewInlineCellStyle->"None",
     InputAutoReplacements->{"TeX"->StyleBox[
             RowBox[ {"T",
               AdjustmentBox[
               "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]],
         "LaTeX"->StyleBox[
             RowBox[ {"L",
               StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001],
                 FontSize -> Smaller], "T",
               AdjustmentBox[
               "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]],
         "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica",
         Inherited},
     LanguageCategory->"NaturalLanguage",
     CounterIncrements->"Subtitle",
     CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
         "Subsubtitle", 0}},
     FontFamily->"Helvetica",
     FontSize->24],

   Cell[StyleData["Subtitle", "Presentation"],
     CellMargins->{{24, 10}, {20, 20}},
     LineSpacing->{1, 0},
     FontSize->36],

   Cell[StyleData["Subtitle", "Condensed"],
     CellMargins->{{8, 10}, {4, 4}},
     FontSize->14],

   Cell[StyleData["Subtitle", "Printout"],
     CellMargins->{{2, 10}, {12, 8}},
     FontSize->18]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["Subsubtitle"],
     CellMargins->{{12, Inherited}, {20, 15}},
     CellGroupingRules->{"TitleGrouping", 20},
     PageBreakBelow->False,
     DefaultNewInlineCellStyle->"None",
     InputAutoReplacements->{"TeX"->StyleBox[
             RowBox[ {"T",
               AdjustmentBox[
               "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]],
         "LaTeX"->StyleBox[
             RowBox[ {"L",
               StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001],
                 FontSize -> Smaller], "T",
               AdjustmentBox[
               "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]],
         "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica",
         Inherited},
     LanguageCategory->"NaturalLanguage",
     CounterIncrements->"Subsubtitle",
     CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
     FontFamily->"Helvetica",
     FontSize->14,
     FontSlant->"Italic"],

   Cell[StyleData["Subsubtitle", "Presentation"],
     CellMargins->{{24, 10}, {20, 20}},
     LineSpacing->{1, 0},
     FontSize->24],

   Cell[StyleData["Subsubtitle", "Condensed"],
     CellMargins->{{8, 10}, {8, 8}},
     FontSize->12],

   Cell[StyleData["Subsubtitle", "Printout"],
     CellMargins->{{2, 10}, {12, 8}},
     FontSize->14]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["Section"],
     CellDingbat->"\[FilledSquare]",
     CellMargins->{{25, Inherited}, {8, 24}},
     CellGroupingRules->{"SectionGrouping", 30},
     PageBreakBelow->False,
     DefaultNewInlineCellStyle->"None",
     InputAutoReplacements->{"TeX"->StyleBox[
             RowBox[ {"T",
               AdjustmentBox[
               "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]],
         "LaTeX"->StyleBox[
             RowBox[ {"L",
               StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001],
                 FontSize -> Smaller], "T",
               AdjustmentBox[
               "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]],
         "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica",
         Inherited},
     LineSpacing->{1, 7},
     LanguageCategory->"NaturalLanguage",
     CounterIncrements->"Section",
     CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
     FontFamily->"Helvetica",
     FontSize->16,
     FontWeight->"Bold"],

   Cell[StyleData["Section", "Presentation"],
     CellMargins->{{40, 10}, {11, 32}},
     LineSpacing->{1, 0},
     FontSize->24],

   Cell[StyleData["Section", "Condensed"],
     CellMargins->{{18, Inherited}, {6, 12}},
     FontSize->12],

   Cell[StyleData["Section", "Printout"],
     CellMargins->{{13, 0}, {7, 22}},
     FontSize->14]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["Subsection"],
     CellDingbat->"\[FilledSmallSquare]",
     CellMargins->{{22, Inherited}, {8, 20}},
     CellGroupingRules->{"SectionGrouping", 40},
     PageBreakBelow->False,
     DefaultNewInlineCellStyle->"None",
     InputAutoReplacements->{"TeX"->StyleBox[
             RowBox[ {"T",
               AdjustmentBox[
               "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]],
         "LaTeX"->StyleBox[
             RowBox[ {"L",
               StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001],
                 FontSize -> Smaller], "T",
               AdjustmentBox[
               "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]],
         "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica",
         Inherited},
     LanguageCategory->"NaturalLanguage",
     CounterIncrements->"Subsection",
     CounterAssignments->{{"Subsubsection", 0}},
     FontFamily->"Times",
     FontSize->14,
     FontWeight->"Bold"],

   Cell[StyleData["Subsection", "Presentation"],
     CellMargins->{{36, 10}, {11, 32}},
     LineSpacing->{1, 0},
     FontSize->22],

   Cell[StyleData["Subsection", "Condensed"],
     CellMargins->{{16, Inherited}, {6, 12}},
     FontSize->12],

   Cell[StyleData["Subsection", "Printout"],
     CellMargins->{{9, 0}, {7, 22}},
     FontSize->12]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["Subsubsection"],
     CellDingbat->"\[FilledSmallSquare]",
     CellMargins->{{22, Inherited}, {8, 18}},
     CellGroupingRules->{"SectionGrouping", 50},
     PageBreakBelow->False,
     DefaultNewInlineCellStyle->"None",
     InputAutoReplacements->{"TeX"->StyleBox[
             RowBox[ {"T",
               AdjustmentBox[
               "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]],
         "LaTeX"->StyleBox[
             RowBox[ {"L",
               StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001],
                 FontSize -> Smaller], "T",
               AdjustmentBox[
               "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]],
         "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica",
         Inherited},
     LanguageCategory->"NaturalLanguage",
     CounterIncrements->"Subsubsection",
     FontFamily->"Times",
     FontWeight->"Bold"],

   Cell[StyleData["Subsubsection", "Presentation"],
     CellMargins->{{34, 10}, {11, 26}},
     LineSpacing->{1, 0},
     FontSize->18],

   Cell[StyleData["Subsubsection", "Condensed"],
     CellMargins->{{17, Inherited}, {6, 12}},
     FontSize->10],

   Cell[StyleData["Subsubsection", "Printout"],
     CellMargins->{{9, 0}, {7, 14}},
     FontSize->11]
   }, Closed]]
   }, Closed]],

   Cell[CellGroupData[{

   Cell["Styles for Body Text", "Section"],

   Cell[CellGroupData[{

   Cell[StyleData["Text"],
     CellMargins->{{12, 10}, {7, 7}},
     InputAutoReplacements->{"TeX"->StyleBox[
             RowBox[ {"T",
               AdjustmentBox[
               "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]],
         "LaTeX"->StyleBox[
             RowBox[ {"L",
               StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001],
                 FontSize -> Smaller], "T",
               AdjustmentBox[
               "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]],
         "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica",
         Inherited},
     Hyphenation->True,
     LineSpacing->{1, 3},
     CounterIncrements->"Text"],

   Cell[StyleData["Text", "Presentation"],
     CellMargins->{{24, 10}, {10, 10}},
     LineSpacing->{1, 5},
     FontSize->16],

   Cell[StyleData["Text", "Condensed"],
     CellMargins->{{8, 10}, {6, 6}},
     LineSpacing->{1, 1},
     FontSize->11],

   Cell[StyleData["Text", "Printout"],
     CellMargins->{{2, 2}, {6, 6}},
     TextJustification->0.5,
     FontSize->10]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["SmallText"],
     CellMargins->{{12, 10}, {6, 6}},
     DefaultNewInlineCellStyle->"None",
     Hyphenation->True,
     LineSpacing->{1, 3},
     LanguageCategory->"NaturalLanguage",
     CounterIncrements->"SmallText",
     FontFamily->"Helvetica",
     FontSize->9],

   Cell[StyleData["SmallText", "Presentation"],
     CellMargins->{{24, 10}, {8, 8}},
     LineSpacing->{1, 5},
     FontSize->12],

   Cell[StyleData["SmallText", "Condensed"],
     CellMargins->{{8, 10}, {5, 5}},
     LineSpacing->{1, 2},
     FontSize->9],

   Cell[StyleData["SmallText", "Printout"],
     CellMargins->{{2, 2}, {5, 5}},
     TextJustification->0.5,
     FontSize->7]
   }, Closed]]
   }, Closed]],

   Cell[CellGroupData[{

   Cell["Styles for Input/Output", "Section"],

   Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],

   Cell[CellGroupData[{

   Cell[StyleData["Input"],
     CellMargins->{{45, 10}, {5, 7}},
     Evaluatable->True,
     CellGroupingRules->"InputGrouping",
     CellHorizontalScrolling->True,
     PageBreakWithin->False,
     GroupPageBreakWithin->False,
     DefaultFormatType->DefaultInputFormatType,
     HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
     AutoItalicWords->{},
     LanguageCategory->"Mathematica",
     FormatType->InputForm,
     ShowStringCharacters->True,
     NumberMarks->True,
     LinebreakAdjustments->{0.85, 2, 10, 0, 1},
     CounterIncrements->"Input",
     FontWeight->"Bold"],

   Cell[StyleData["Input", "Presentation"],
     CellMargins->{{72, Inherited}, {8, 10}},
     LineSpacing->{1, 0},
     FontSize->16],

   Cell[StyleData["Input", "Condensed"],
     CellMargins->{{40, 10}, {2, 3}},
     FontSize->11],

   Cell[StyleData["Input", "Printout"],
     CellMargins->{{39, 0}, {4, 6}},
     LinebreakAdjustments->{0.85, 2, 10, 1, 1},
     FontSize->9]
   }, Closed]],

   Cell[StyleData["InputOnly"],
     Evaluatable->True,
     CellGroupingRules->"InputGrouping",
     CellHorizontalScrolling->True,
     DefaultFormatType->DefaultInputFormatType,
     HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
     AutoItalicWords->{},
     LanguageCategory->"Mathematica",
     FormatType->InputForm,
     ShowStringCharacters->True,
     NumberMarks->True,
     LinebreakAdjustments->{0.85, 2, 10, 0, 1},
     CounterIncrements->"Input",
     StyleMenuListing->None,
     FontWeight->"Bold"],

   Cell[CellGroupData[{

   Cell[StyleData["Output"],
     CellMargins->{{47, 10}, {7, 5}},
     CellEditDuplicate->True,
     CellGroupingRules->"OutputGrouping",
     CellHorizontalScrolling->True,
     PageBreakWithin->False,
     GroupPageBreakWithin->False,
     GeneratedCell->True,
     CellAutoOverwrite->True,
     DefaultFormatType->DefaultOutputFormatType,
     HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
     AutoItalicWords->{},
     LanguageCategory->None,
     FormatType->InputForm,
     CounterIncrements->"Output"],

   Cell[StyleData["Output", "Presentation"],
     CellMargins->{{72, Inherited}, {10, 8}},
     LineSpacing->{1, 0},
     FontSize->16],

   Cell[StyleData["Output", "Condensed"],
     CellMargins->{{41, Inherited}, {3, 2}},
     FontSize->11],

   Cell[StyleData["Output", "Printout"],
     CellMargins->{{39, 0}, {6, 4}},
     FontSize->9]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["Message"],
     CellMargins->{{45, Inherited}, {Inherited, Inherited}},
     CellGroupingRules->"OutputGrouping",
     PageBreakWithin->False,
     GroupPageBreakWithin->False,
     GeneratedCell->True,
     CellAutoOverwrite->True,
     ShowCellLabel->False,
     DefaultFormatType->DefaultOutputFormatType,
     HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
     AutoItalicWords->{},
     LanguageCategory->None,
     FormatType->InputForm,
     CounterIncrements->"Message",
     StyleMenuListing->None,
     FontSize->11,
     FontColor->RGBColor[0, 0, 1]],

   Cell[StyleData["Message", "Presentation"],
     CellMargins->{{72, Inherited}, {Inherited, Inherited}},
     LineSpacing->{1, 0},
     FontSize->16],

   Cell[StyleData["Message", "Condensed"],
     CellMargins->{{41, Inherited}, {Inherited, Inherited}},
     FontSize->11],

   Cell[StyleData["Message", "Printout"],
     CellMargins->{{39, Inherited}, {Inherited, Inherited}},
     FontSize->7,
     FontColor->GrayLevel[0]]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["Print"],
     CellMargins->{{45, Inherited}, {Inherited, Inherited}},
     CellGroupingRules->"OutputGrouping",
     CellHorizontalScrolling->True,
     PageBreakWithin->False,
     GroupPageBreakWithin->False,
     GeneratedCell->True,
     CellAutoOverwrite->True,
     ShowCellLabel->False,
     DefaultFormatType->DefaultOutputFormatType,
     HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
     AutoItalicWords->{},
     LanguageCategory->None,
     FormatType->InputForm,
     CounterIncrements->"Print",
     StyleMenuListing->None],

   Cell[StyleData["Print", "Presentation"],
     CellMargins->{{72, Inherited}, {Inherited, Inherited}},
     LineSpacing->{1, 0},
     FontSize->16],

   Cell[StyleData["Print", "Condensed"],
     CellMargins->{{41, Inherited}, {Inherited, Inherited}},
     FontSize->11],

   Cell[StyleData["Print", "Printout"],
     CellMargins->{{39, Inherited}, {Inherited, Inherited}},
     FontSize->8]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["Graphics"],
     CellMargins->{{4, Inherited}, {Inherited, Inherited}},
     CellGroupingRules->"GraphicsGrouping",
     CellHorizontalScrolling->True,
     PageBreakWithin->False,
     GeneratedCell->True,
     CellAutoOverwrite->True,
     ShowCellLabel->False,
     DefaultFormatType->DefaultOutputFormatType,
     LanguageCategory->None,
     FormatType->InputForm,
     CounterIncrements->"Graphics",
     ImageMargins->{{43, Inherited}, {Inherited, 0}},
     StyleMenuListing->None,
     FontFamily->"Courier",
     FontSize->10],

   Cell[StyleData["Graphics", "Presentation"],
     ImageMargins->{{62, Inherited}, {Inherited, 0}}],

   Cell[StyleData["Graphics", "Condensed"],
     ImageMargins->{{38, Inherited}, {Inherited, 0}},
     Magnification->0.6],

   Cell[StyleData["Graphics", "Printout"],
     ImageMargins->{{30, Inherited}, {Inherited, 0}},
     Magnification->0.8]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["CellLabel"],
     LanguageCategory->None,
     StyleMenuListing->None,
     FontFamily->"Helvetica",
     FontSize->9,
     FontColor->RGBColor[0, 0, 1]],

   Cell[StyleData["CellLabel", "Presentation"],
     FontSize->12],

   Cell[StyleData["CellLabel", "Condensed"],
     FontSize->9],

   Cell[StyleData["CellLabel", "Printout"],
     FontFamily->"Courier",
     FontSize->8,
     FontSlant->"Italic",
     FontColor->GrayLevel[0]]
   }, Closed]]
   }, Closed]],

   Cell[CellGroupData[{

   Cell["Inline Formatting", "Section"],

   Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],

   Cell[StyleData["RM"],
     StyleMenuListing->None,
     FontWeight->"Plain",
     FontSlant->"Plain"],

   Cell[StyleData["BF"],
     StyleMenuListing->None,
     FontWeight->"Bold"],

   Cell[StyleData["IT"],
     StyleMenuListing->None,
     FontSlant->"Italic"],

   Cell[StyleData["TR"],
     StyleMenuListing->None,
     FontFamily->"Times",
     FontWeight->"Plain",
     FontSlant->"Plain"],

   Cell[StyleData["TI"],
     StyleMenuListing->None,
     FontFamily->"Times",
     FontWeight->"Plain",
     FontSlant->"Italic"],

   Cell[StyleData["TB"],
     StyleMenuListing->None,
     FontFamily->"Times",
     FontWeight->"Bold",
     FontSlant->"Plain"],

   Cell[StyleData["TBI"],
     StyleMenuListing->None,
     FontFamily->"Times",
     FontWeight->"Bold",
     FontSlant->"Italic"],

   Cell[StyleData["MR"],
     HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
     StyleMenuListing->None,
     FontFamily->"Courier",
     FontWeight->"Plain",
     FontSlant->"Plain"],

   Cell[StyleData["MO"],
     HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
     StyleMenuListing->None,
     FontFamily->"Courier",
     FontWeight->"Plain",
     FontSlant->"Italic"],

   Cell[StyleData["MB"],
     HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
     StyleMenuListing->None,
     FontFamily->"Courier",
     FontWeight->"Bold",
     FontSlant->"Plain"],

   Cell[StyleData["MBO"],
     HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
     StyleMenuListing->None,
     FontFamily->"Courier",
     FontWeight->"Bold",
     FontSlant->"Italic"],

   Cell[StyleData["SR"],
     StyleMenuListing->None,
     FontFamily->"Helvetica",
     FontWeight->"Plain",
     FontSlant->"Plain"],

   Cell[StyleData["SO"],
     StyleMenuListing->None,
     FontFamily->"Helvetica",
     FontWeight->"Plain",
     FontSlant->"Italic"],

   Cell[StyleData["SB"],
     StyleMenuListing->None,
     FontFamily->"Helvetica",
     FontWeight->"Bold",
     FontSlant->"Plain"],

   Cell[StyleData["SBO"],
     StyleMenuListing->None,
     FontFamily->"Helvetica",
     FontWeight->"Bold",
     FontSlant->"Italic"],

   Cell[CellGroupData[{

   Cell[StyleData["SO10"],
     StyleMenuListing->None,
     FontFamily->"Helvetica",
     FontSize->10,
     FontWeight->"Plain",
     FontSlant->"Italic"],

   Cell[StyleData["SO10", "Printout"],
     StyleMenuListing->None,
     FontFamily->"Helvetica",
     FontSize->7,
     FontWeight->"Plain",
     FontSlant->"Italic"],

   Cell[StyleData["SO10", "EnhancedPrintout"],
     StyleMenuListing->None,
     FontFamily->"Futura",
     FontSize->7,
     FontWeight->"Plain",
     FontSlant->"Italic"]
   }, Closed]]
   }, Closed]],

   Cell[CellGroupData[{

   Cell["Formulas and Programming", "Section"],

   Cell[CellGroupData[{

   Cell[StyleData["InlineFormula"],
     CellMargins->{{10, 4}, {0, 8}},
     CellHorizontalScrolling->True,
     HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
     LanguageCategory->"Formula",
     ScriptLevel->1,
     SingleLetterItalics->True],

   Cell[StyleData["InlineFormula", "Presentation"],
     CellMargins->{{24, 10}, {10, 10}},
     LineSpacing->{1, 5},
     FontSize->16],

   Cell[StyleData["InlineFormula", "Condensed"],
     CellMargins->{{8, 10}, {6, 6}},
     LineSpacing->{1, 1},
     FontSize->11],

   Cell[StyleData["InlineFormula", "Printout"],
     CellMargins->{{2, 0}, {6, 6}},
     FontSize->10]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["DisplayFormula"],
     CellMargins->{{42, Inherited}, {Inherited, Inherited}},
     CellHorizontalScrolling->True,
     DefaultFormatType->DefaultInputFormatType,
     HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
     LanguageCategory->"Formula",
     ScriptLevel->0,
     SingleLetterItalics->True,
     UnderoverscriptBoxOptions->{LimitsPositioning->True}],

   Cell[StyleData["DisplayFormula", "Presentation"],
     LineSpacing->{1, 5},
     FontSize->16],

   Cell[StyleData["DisplayFormula", "Condensed"],
     LineSpacing->{1, 1},
     FontSize->11],

   Cell[StyleData["DisplayFormula", "Printout"],
     FontSize->10]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["Program"],
     CellFrame->{{0, 0}, {0.5, 0.5}},
     CellMargins->{{10, 4}, {0, 8}},
     CellHorizontalScrolling->True,
     Hyphenation->False,
     LanguageCategory->"Formula",
     ScriptLevel->1,
     FontFamily->"Courier"],

   Cell[StyleData["Program", "Presentation"],
     CellMargins->{{24, 10}, {10, 10}},
     LineSpacing->{1, 5},
     FontSize->16],

   Cell[StyleData["Program", "Condensed"],
     CellMargins->{{8, 10}, {6, 6}},
     LineSpacing->{1, 1},
     FontSize->11],

   Cell[StyleData["Program", "Printout"],
     CellMargins->{{2, 0}, {6, 6}},
     FontSize->9]
   }, Closed]]
   }, Closed]],

   Cell[CellGroupData[{

   Cell["Outline Styles", "Section"],

   Cell[CellGroupData[{

   Cell[StyleData["Outline1"],
     CellMargins->{{12, 10}, {7, 7}},
     CellGroupingRules->{"SectionGrouping", 50},
     ParagraphIndent->-38,
     CounterIncrements->"Outline1",
     FontSize->18,
     FontWeight->"Bold",
     CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}],

   Cell[StyleData["Outline1", "Printout"],
     CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["Outline2"],
     CellMargins->{{59, 10}, {7, 7}},
     CellGroupingRules->{"SectionGrouping", 60},
     ParagraphIndent->-27,
     CounterIncrements->"Outline2",
     FontSize->15,
     FontWeight->"Bold",
     CounterBoxOptions->{CounterFunction:>(Part[
         CharacterRange[ "A", "Z"], #]&)}],

   Cell[StyleData["Outline2", "Printout"],
     CounterBoxOptions->{CounterFunction:>(Part[
         CharacterRange[ "A", "Z"], #]&)}]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["Outline3"],
     CellMargins->{{108, 10}, {7, 7}},
     CellGroupingRules->{"SectionGrouping", 70},
     ParagraphIndent->-21,
     CounterIncrements->"Outline3",
     FontSize->12,
     CounterBoxOptions->{CounterFunction:>Identity}],

   Cell[StyleData["Outline3", "Printout"],
     CounterBoxOptions->{CounterFunction:>Identity}]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["Outline4"],
     CellMargins->{{158, 10}, {7, 7}},
     CellGroupingRules->{"SectionGrouping", 80},
     ParagraphIndent->-18,
     CounterIncrements->"Outline4",
     FontSize->10,
     CounterBoxOptions->{CounterFunction:>(Part[
         CharacterRange[ "a", "z"], #]&)}],

   Cell[StyleData["Outline4", "Printout"]]
   }, Closed]]
   }, Closed]],

   Cell[CellGroupData[{

   Cell["Hyperlink Styles", "Section"],

   Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

   Cell[CellGroupData[{

   Cell[StyleData["Hyperlink"],
     StyleMenuListing->None,
     ButtonStyleMenuListing->Automatic,
     FontColor->RGBColor[0, 0, 1],
     FontVariations->{"Underline"->True},
     ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
         FrontEnd`NotebookLocate[ #2]}]&),
     Active->True,
     ButtonNote->ButtonData}],

   Cell[StyleData["Hyperlink", "Presentation"],
     FontSize->16],

   Cell[StyleData["Hyperlink", "Condensed"],
     FontSize->11],

   Cell[StyleData["Hyperlink", "Printout"],
     FontSize->10,
     FontColor->GrayLevel[0],
     FontVariations->{"Underline"->False}]
   }, Closed]],

   Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],

   Cell[CellGroupData[{

   Cell[StyleData["MainBookLink"],
     StyleMenuListing->None,
     ButtonStyleMenuListing->Automatic,
     FontColor->RGBColor[0, 0, 1],
     FontVariations->{"Underline"->True},
     ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
         FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
     Active->True,
     ButtonFrame->"None"}],

   Cell[StyleData["MainBookLink", "Presentation"],
     FontSize->16],

   Cell[StyleData["MainBookLink", "Condensed"],
     FontSize->11],

   Cell[StyleData["MainBookLink", "Printout"],
     FontSize->10,
     FontColor->GrayLevel[0],
     FontVariations->{"Underline"->False}]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["AddOnsLink"],
     StyleMenuListing->None,
     ButtonStyleMenuListing->Automatic,
     FontFamily->"Courier",
     FontColor->RGBColor[0, 0, 1],
     FontVariations->{"Underline"->True},
     ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
         FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
     Active->True,
     ButtonFrame->"None"}],

   Cell[StyleData["AddOnsLink", "Presentation"],
     FontSize->16],

   Cell[StyleData["AddOnsLink", "Condensed"],
     FontSize->11],

   Cell[StyleData["AddOnsLink", "Printout"],
     FontSize->10,
     FontColor->GrayLevel[0],
     FontVariations->{"Underline"->False}]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["RefGuideLink"],
     StyleMenuListing->None,
     ButtonStyleMenuListing->Automatic,
     FontFamily->"Courier",
     FontColor->RGBColor[0, 0, 1],
     FontVariations->{"Underline"->True},
     ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
         FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
     Active->True,
     ButtonFrame->"None"}],

   Cell[StyleData["RefGuideLink", "Presentation"],
     FontSize->16],

   Cell[StyleData["RefGuideLink", "Condensed"],
     FontSize->11],

   Cell[StyleData["RefGuideLink", "Printout"],
     FontSize->10,
     FontColor->GrayLevel[0],
     FontVariations->{"Underline"->False}]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["GettingStartedLink"],
     StyleMenuListing->None,
     ButtonStyleMenuListing->Automatic,
     FontColor->RGBColor[0, 0, 1],
     FontVariations->{"Underline"->True},
     ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
         FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
     Active->True,
     ButtonFrame->"None"}],

   Cell[StyleData["GettingStartedLink", "Presentation"],
     FontSize->16],

   Cell[StyleData["GettingStartedLink", "Condensed"],
     FontSize->11],

   Cell[StyleData["GettingStartedLink", "Printout"],
     FontSize->10,
     FontColor->GrayLevel[0],
     FontVariations->{"Underline"->False}]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["OtherInformationLink"],
     StyleMenuListing->None,
     ButtonStyleMenuListing->Automatic,
     FontColor->RGBColor[0, 0, 1],
     FontVariations->{"Underline"->True},
     ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
         FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
     Active->True,
     ButtonFrame->"None"}],

   Cell[StyleData["OtherInformationLink", "Presentation"],
     FontSize->16],

   Cell[StyleData["OtherInformationLink", "Condensed"],
     FontSize->11],

   Cell[StyleData["OtherInformationLink", "Printout"],
     FontSize->10,
     FontColor->GrayLevel[0],
     FontVariations->{"Underline"->False}]
   }, Closed]]
   }, Closed]],

   Cell[CellGroupData[{

   Cell["Styles for Headers and Footers", "Section"],

   Cell[StyleData["Header"],
     CellMargins->{{0, 0}, {4, 1}},
     DefaultNewInlineCellStyle->"None",
     LanguageCategory->"NaturalLanguage",
     StyleMenuListing->None,
     FontSize->10,
     FontSlant->"Italic"],

   Cell[StyleData["Footer"],
     CellMargins->{{0, 0}, {0, 4}},
     DefaultNewInlineCellStyle->"None",
     LanguageCategory->"NaturalLanguage",
     StyleMenuListing->None,
     FontSize->9,
     FontSlant->"Italic"],

   Cell[StyleData["PageNumber"],
     CellMargins->{{0, 0}, {4, 1}},
     StyleMenuListing->None,
     FontFamily->"Times",
     FontSize->10]
   }, Closed]],

   Cell[CellGroupData[{

   Cell["Palette Styles", "Section"],

   Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],

   Cell[StyleData["Paste"],
     StyleMenuListing->None,
     ButtonStyleMenuListing->Automatic,
     ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
         FrontEnd`NotebookApply[
           FrontEnd`InputNotebook[ ], #, After]}]&)}],

   Cell[StyleData["Evaluate"],
     StyleMenuListing->None,
     ButtonStyleMenuListing->Automatic,
     ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
         FrontEnd`NotebookApply[
           FrontEnd`InputNotebook[ ], #, All],
         SelectionEvaluate[
           FrontEnd`InputNotebook[ ], All]}]&)}],

   Cell[StyleData["EvaluateCell"],
     StyleMenuListing->None,
     ButtonStyleMenuListing->Automatic,
     ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
         FrontEnd`NotebookApply[
           FrontEnd`InputNotebook[ ], #, All],
         FrontEnd`SelectionMove[
           FrontEnd`InputNotebook[ ], All, Cell, 1],
         FrontEnd`SelectionEvaluateCreateCell[
           FrontEnd`InputNotebook[ ], All]}]&)}],

   Cell[StyleData["CopyEvaluate"],
     StyleMenuListing->None,
     ButtonStyleMenuListing->Automatic,
     ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
         FrontEnd`SelectionCreateCell[
           FrontEnd`InputNotebook[ ], All],
         FrontEnd`NotebookApply[
           FrontEnd`InputNotebook[ ], #, All],
         FrontEnd`SelectionEvaluate[
           FrontEnd`InputNotebook[ ], All]}]&)}],

   Cell[StyleData["CopyEvaluateCell"],
     StyleMenuListing->None,
     ButtonStyleMenuListing->Automatic,
     ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
         FrontEnd`SelectionCreateCell[
           FrontEnd`InputNotebook[ ], All],
         FrontEnd`NotebookApply[
           FrontEnd`InputNotebook[ ], #, All],
         FrontEnd`SelectionEvaluateCreateCell[
           FrontEnd`InputNotebook[ ], All]}]&)}]
   }, Closed]],

   Cell[CellGroupData[{

   Cell["Placeholder Styles", "Section"],

   Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],

   Cell[CellGroupData[{

   Cell[StyleData["Placeholder"],
     Placeholder->True,
     StyleMenuListing->None,
     FontSlant->"Italic",
     FontColor->RGBColor[0.890623, 0.864698, 0.384756],
     TagBoxOptions->{Editable->False,
     Selectable->False,
     StripWrapperBoxes->False}],

   Cell[StyleData["Placeholder", "Presentation"]],

   Cell[StyleData["Placeholder", "Condensed"]],

   Cell[StyleData["Placeholder", "Printout"]]
   }, Closed]],

   Cell[CellGroupData[{

   Cell[StyleData["PrimaryPlaceholder"],
     StyleMenuListing->None,
     DrawHighlighted->True,
     FontSlant->"Italic",
     Background->RGBColor[0.912505, 0.891798, 0.507774],
     TagBoxOptions->{Editable->False,
     Selectable->False,
     StripWrapperBoxes->False}],

   Cell[StyleData["PrimaryPlaceholder", "Presentation"]],

   Cell[StyleData["PrimaryPlaceholder", "Condensed"]],

   Cell[StyleData["PrimaryPlaceholder", "Printout"]]
   }, Closed]]
   }, Closed]],

   Cell[CellGroupData[{

   Cell["FormatType Styles", "Section"],

   Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],

   Cell[StyleData["CellExpression"],
     PageWidth->Infinity,
     CellMargins->{{6, Inherited}, {Inherited, Inherited}},
     ShowCellLabel->False,
     ShowSpecialCharacters->False,
     AllowInlineCells->False,
     Hyphenation->False,
     AutoItalicWords->{},
     StyleMenuListing->None,
     FontFamily->"Courier",
     FontSize->12,
     Background->GrayLevel[1]],

   Cell[StyleData["InputForm"],
     InputAutoReplacements->{},
     AllowInlineCells->False,
     Hyphenation->False,
     StyleMenuListing->None,
     FontFamily->"Courier"],

   Cell[StyleData["OutputForm"],
     PageWidth->Infinity,
     TextAlignment->Left,
     LineSpacing->{0.6, 1},
     StyleMenuListing->None,
     FontFamily->"Courier"],

   Cell[StyleData["StandardForm"],
     InputAutoReplacements->{
       "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]",
         ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]",
         Inherited},
     LineSpacing->{1.25, 0},
     StyleMenuListing->None,
     FontFamily->"Courier"],

   Cell[StyleData["TraditionalForm"],
     InputAutoReplacements->{
       "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]",
         ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]",
         Inherited},
     LineSpacing->{1.25, 0},
     SingleLetterItalics->True,
     TraditionalFunctionNotation->True,
     DelimiterMatching->None,
     StyleMenuListing->None],

   Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],

   Cell[StyleData["InlineCell"],
     LanguageCategory->"Formula",
     ScriptLevel->1,
     StyleMenuListing->None],

   Cell[StyleData["InlineCellEditing"],
     StyleMenuListing->None,
     Background->RGBColor[1, 0.749996, 0.8]]
   }, Closed]],

   Cell[CellGroupData[{

   Cell["Automatic Styles", "Section"],

   Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],

   Cell[StyleData["UnmatchedBracket"],
     StyleMenuListing->None,
     FontColor->RGBColor[0.760006, 0.330007, 0.8]]
   }, Closed]]
   }, Open  ]],

   Cell[CellGroupData[{

   Cell["Notation Package Styles", "Section",
     GeneratedCell->True,
     CellTags->"NotationPackage"],

   Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
     GeneratedCell->True,
     CellTags->"NotationPackage"],

   Cell[StyleData["NotationTemplateStyle"],
     GeneratedCell->True,
     StyleMenuListing->None,
     Background->RGBColor[1, 1, 0.850004],
     TagBoxOptions->{SyntaxForm->"symbol"},
     CellTags->"NotationPackage"],

   Cell[StyleData["NotationPatternWrapperStyle"],
     GeneratedCell->True,
     StyleMenuListing->None,
     Background->RGBColor[1, 0.900008, 0.979995],
     TagBoxOptions->{SyntaxForm->"symbol"},
     CellTags->"NotationPackage"],

   Cell[StyleData["NotationMadeBoxesWrapperStyle"],
     GeneratedCell->True,
     StyleMenuListing->None,
     Background->RGBColor[0.900008, 0.889998, 1],
     TagBoxOptions->{SyntaxForm->"symbol"},
     CellTags->"NotationPackage"]
   }, Closed]]
   }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000cP2>?ogoo<3@@960dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000008000
00000000004000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
   "Title"->{
     Cell[1727, 52, 245, 10, 156, "Title",
       CellTags->"Title"]},
   "Subsection: Hartree-Fock Evaluation"->{
     Cell[27195, 720, 180, 8, 46, "Subsection",
       CellTags->"Subsection: Hartree-Fock Evaluation"]}
   }
*)

(*CellTagsIndex
CellTagsIndex->{
   {"Title", 94790, 2821},
   {"Subsection: Hartree-Fock Evaluation", 94902, 2824}
   }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 245, 10, 156, "Title",
   CellTags->"Title"],
Cell[1975, 64, 321, 9, 32, "Text"],
Cell[2299, 75, 469, 9, 64, "Text"],
Cell[2771, 86, 136, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[2932, 93, 95, 5, 56, "Section"],

Cell[CellGroupData[{
Cell[3052, 102, 120, 7, 46, "Subsection"],
Cell[3175, 111, 140, 3, 30, "Text"],
Cell[3318, 116, 137, 3, 28, "Input",
   InitializationCell->True],
Cell[3458, 121, 110, 2, 28, "Input",
   InitializationCell->True],
Cell[3571, 125, 149, 3, 28, "Input",
   InitializationCell->True],
Cell[3723, 130, 525, 13, 31, "Input",
   InitializationCell->True],
Cell[4251, 145, 681, 17, 30, "Input",
   InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4969, 167, 121, 7, 46, "Subsection"],
Cell[5093, 176, 101, 3, 30, "Text"],
Cell[5197, 181, 231, 5, 39, "Input",
   InitializationCell->True],
Cell[5431, 188, 139, 3, 30, "Text"],
Cell[5573, 193, 537, 11, 82, "Input",
   InitializationCell->True],
Cell[6113, 206, 148, 3, 30, "Text"],
Cell[6264, 211, 1438, 30, 31, "Input",
   InitializationCell->True],
Cell[7705, 243, 675, 16, 29, "Input",
   InitializationCell->True],
Cell[8383, 261, 109, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[8517, 268, 147, 4, 42, "Subsubsection"],
Cell[8667, 274, 471, 12, 43, "Input",
   InitializationCell->True],
Cell[9141, 288, 158, 3, 29, "Input",
   InitializationCell->True],
Cell[9302, 293, 188, 4, 43, "Input",
   InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9527, 302, 139, 4, 42, "Subsubsection"],
Cell[9669, 308, 327, 9, 43, "Input",
   InitializationCell->True],
Cell[9999, 319, 114, 2, 29, "Input",
   InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10150, 326, 161, 4, 42, "Subsubsection"],
Cell[10314, 332, 190, 5, 34, "Text"],
Cell[10507, 339, 1882, 39, 63, "Input",
   InitializationCell->True],
Cell[12392, 380, 107, 3, 30, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12536, 388, 152, 4, 43, "Subsubsection"],
Cell[12691, 394, 2093, 39, 99, "Input",
   InitializationCell->True],
Cell[14787, 435, 67, 2, 30, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[14891, 442, 245, 7, 43, "Subsubsection"],
Cell[15139, 451, 1447, 28, 99, "Input",
   InitializationCell->True],
Cell[16589, 481, 67, 2, 30, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[16693, 488, 146, 6, 42, "Subsubsection"],
Cell[16842, 496, 1172, 24, 65, "Input",
   InitializationCell->True],
Cell[18017, 522, 2201, 46, 83, "Input",
   InitializationCell->True],
Cell[20221, 570, 289, 10, 30, "Text"],
Cell[20513, 582, 1047, 17, 155, "Input",
   InitializationCell->True],
Cell[21563, 601, 1047, 17, 155, "Input",
   InitializationCell->True],
Cell[22613, 620, 21, 0, 30, "Text"],
Cell[22637, 622, 284, 5, 43, "Input",
   InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22970, 633, 130, 7, 46, "Subsection"],
Cell[23103, 642, 70, 0, 30, "Text"],
Cell[23176, 644, 3982, 71, 430, "Input",
   InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[27195, 720, 180, 8, 46, "Subsection",
   CellTags->"Subsection: Hartree-Fock Evaluation"],
Cell[27378, 730, 800, 22, 70, "Text"],
Cell[28181, 754, 1399, 25, 316, "Input",
   InitializationCell->True],
Cell[29583, 781, 1259, 39, 68, "Text"],
Cell[30845, 822, 1697, 31, 244, "Input",
   InitializationCell->True],
Cell[32545, 855, 623, 20, 32, "Text"],
Cell[33171, 877, 2103, 44, 119, "Input",
   InitializationCell->True],
Cell[35277, 923, 190, 4, 52, "Input",
   InitializationCell->True],
Cell[35470, 929, 202, 5, 32, "Text"],
Cell[35675, 936, 2646, 52, 144, "Input",
   InitializationCell->True],
Cell[38324, 990, 585, 17, 48, "Text"],
Cell[38912, 1009, 353, 7, 100, "Input",
   InitializationCell->True],
Cell[39268, 1018, 881, 21, 64, "Text"],
Cell[40152, 1041, 1268, 22, 226, "Input",
   InitializationCell->True],
Cell[41423, 1065, 205, 4, 30, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[41677, 1075, 95, 5, 36, "Section"],
Cell[41775, 1082, 886, 30, 68, "Text"],
Cell[42664, 1114, 67, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[42756, 1119, 147, 7, 46, "Subsection"],
Cell[42906, 1128, 451, 17, 34, "Text"],
Cell[43360, 1147, 73, 1, 28, "Input"],
Cell[43436, 1150, 374, 12, 32, "Text"],
Cell[43813, 1164, 126, 2, 43, "Input"],
Cell[43942, 1168, 140, 2, 43, "Input"],
Cell[44085, 1172, 423, 11, 46, "Text"],
Cell[44511, 1185, 102, 2, 29, "Input"],
Cell[44616, 1189, 104, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[44745, 1196, 121, 2, 28, "Input"],
Cell[44869, 1200, 262, 5, 22, "Print"],
Cell[45134, 1207, 206, 4, 22, "Print"],
Cell[45343, 1213, 233, 5, 25, "Print"],
Cell[45579, 1220, 267, 6, 22, "Print"],
Cell[45849, 1228, 265, 6, 22, "Print"]
}, Closed]],
Cell[46129, 1237, 48, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[46202, 1241, 121, 2, 28, "Input"],
Cell[46326, 1245, 264, 5, 22, "Print"],
Cell[46593, 1252, 206, 4, 22, "Print"],
Cell[46802, 1258, 234, 5, 25, "Print"],
Cell[47039, 1265, 280, 6, 22, "Print"],
Cell[47322, 1273, 266, 6, 22, "Print"]
}, Closed]],
Cell[47603, 1282, 492, 13, 50, "Text"],
Cell[48098, 1297, 490, 13, 48, "Text"],
Cell[48591, 1312, 1018, 18, 94, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[49646, 1335, 134, 7, 46, "Subsection"],
Cell[49783, 1344, 763, 22, 70, "Text"],
Cell[50549, 1368, 74, 1, 28, "Input"],
Cell[50626, 1371, 2757, 58, 49, "Input"],
Cell[53386, 1431, 70, 0, 30, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)
